
%%This script computes the stresses and fatigue from the strains and
%%integrate the accelerations to displacements for the NDP experimental
%%data with 75% strake coverage. 

clear all
close all

% Calculate the fatigue damage for 22 straked NDP cases

Fs=1200;    %Sampling frequency
dt=1/Fs;

Do=0.027;   %Outer diameter
E=36.2e9;   %Elastic modulus

load icasesstrakes2.txt -ascii             %Cases and time-windows defined
ncases = length(icasesstrakes2(:,1));      %Number of cases
U = 0.4:0.2:2.4;
U(12:22)=U;
%%
for ic = 1:22 % Start loop over number of cases
    %% load data
    str_icase = int2str(icasesstrakes2(ic,1));
    testnrr = [str_icase]                %Name of case
    testnr = ['test',str_icase,'.mat'];  %From mat file
    eval(['load ',testnr ]);             %Load model test results
    
    
    t1 = icasesstrakes2(ic,2);   %Start analysis at time given in icasesstrakes2.txt
    t2 = icasesstrakes2(ic,3);   %End analysis at time given in icasesstrakes2.txt
    
     %Strouhal frequency
    S=0.17;
    f_disp = U(ic)*S/Do/8;    
    %CF cut-off frequencies
    %hp-lp: filtering bandwidth of the 1xw frequency component  From fdisp to 1.5xw
    if f_disp<0.75
        hpCF = 0.75; 
    else
    hpCF =  f_disp;
    end
    lpCF = icasesstrakes2(ic,5);   %lp Hz, 1.5xw
    %hhp-hlp: filtering bandwidth of the 3xw frequency component
    hhpCF = icasesstrakes2(ic,6);  % hhp Hz,
    hlpCF = icasesstrakes2(ic,7);  % hlp. From 2.5xw to 3.5xw

    %IL cut-off frequencies
    %hp-lp: filtering bandwidth of the 2xw frequency component from
    %2*f_disp to 2.5xw
    hpIL = f_disp*2; 
    if hpIL < 0.75
        hpIL=0.75; 
    end
    
    lpIL = icasesstrakes2(ic,6); % lp Hz, 2.5xw
    %hp-lp: filtering bandwidth of the 4xw frequency component
    hhpIL = icasesstrakes2(ic,7); % hp Hz
    hlpIL = 9*icasesstrakes2(ic,4); % lp. From 3.5xw to 4.5xw
    
    % %Analysis time window
    tst=t1*Fs;
    ted=t2*Fs;
    %     nt=ted-tst+1;
    
    % load CF strain data
    S_data= double(data(47:70,:));  %24 channels of the CF strain signal
    
    % load CF acc data
    ay_data= double(data(79:86,:));  % Measured CF acceleration signals from channel 79-86
    
    %load towing velocity
    U_c = double(data(95,:)); 
    
    % load IL strain data
    N_data= double(data(7:46,:));  %40 channels of the IL strain signal

    % load IL acc data    
    ax_data= double(data(71:78,:));  % Measured IL acceleration signals from channel 71-78
     

    %Load riser effective tension 
    eff_toptens=double(data(116,:)); %Measured force in y-dir at riser top from channel 116 
    eff_bottens=double(data(119,:)); %Measured force in y-dir at riser bottom from channel 119 
    
    nm = length(S_data);              % Number of measurement time steps
    time = [0:nm-1]*dt;               % Time (sec)
    nt = (t2-t1)*Fs;                  % Number of selected time steps
    nst = t1*Fs;                      % Start time step
    
%     close all
    cd('C:\Users\dreng\OneDrive\Dokumenter\NTNU\Riflex_run\Inputfile\STRAKES2\Experiment\Time series')
    figure
    plot(time,ax_data(4,:),time,ay_data(4,:))
    xlabel('Time (s)')
    ylabel('Acceleration (m/s^{2})')
    legend('IL','CF')
    grid on
    title(['Acceleration time series' testnrr])
    saveas(gcf,['acctimeseries' testnrr])
    
    figure
    plot(time,U_c)
    xlabel('Time (s)')
    ylabel('Speed (m/s)')
    title(['Towing speed time series' testnrr])
    saveas(gcf,['veltimeseries' testnrr])
    
    figure
    plot(time,eff_toptens, time, eff_bottens)
    xlabel('Time (s)')
    ylabel('Tension (N)')
    legend('Top tension', 'Bottom tension')
    grid on
    title(['Tension time series' testnrr])
    saveas(gcf,['top&bottensiontimeseries' testnrr])    
    
    
    S_data(:,1:nst)=[];
    S_data(:,nt+1:nm-nst)=[];      %S_data
    
    ay_data(:,1:nst)=[];            % Select data from nst+1:nst+nt
    ay_data(:,nt+1:nm-nst)=[];
    
    N_data(:,1:nst)=[];
    N_data(:,nt+1:nm-nst)=[];
    
    eff_toptens(:,1:nst)=[]; 
    eff_toptens(:,nt+1:nm-nst)=[]; 
    
   
    
    ax_data(:,1:nst)=[];            
    ax_data(:,nt+1:nm-nst)=[];
    
    time(:,1:nst)=[];
    time(:,nt+1:nm-nst)=[];
    
    
    
    %% calculate CF and IL displacement
    [c,k]=size(ay_data);
    
    %Set the displacement as empty matrices before running a new case as
    %the time series are of different length
    Ay=[];
    Ay2=[]; 
    Ay3=[]; 
    Ax=[];
    Ax2=[]; 
    Ax3=[]; 
    
    for i=1:c
        ay=ay_data(i,:);
        Ay(i,:)=acc2displ(ay,Fs,hpCF,hlpCF); %1w to 3w
        Ay2(i,:)=acc2displ(ay,Fs,hpCF,lpCF); %Only 1w
        Ay3(i,:)=acc2displ(ay,Fs,hhpCF,hlpCF); %Only 3w
        ADy(ic,i)=std(Ay(i,:))/Do;
        ADy2(ic,i)=std(Ay2(i,:))/Do;
        ADy3(ic,i)=std(Ay3(i,:))/Do;
    end
    
    [c,k]=size(ax_data);
    
    for i=1:c
        ax=ax_data(i,:);
        Ax(i,:)=acc2displ(ax,Fs,hpIL,hlpIL); %1w to 3w
        Ax2(i,:)=acc2displ(ax,Fs,hpIL,lpIL); %1w
        Ax3(i,:)=acc2displ(ax,Fs,hhpIL,hlpIL); %3w
        ADx(ic,i)=std(Ax(i,:))/Do;
        ADx2(ic,i)=std(Ax2(i,:))/Do;
        ADx3(ic,i)=std(Ax3(i,:))/Do;
    end
    
    %set directory for storing trajectories
    cd('C:\Users\dreng\OneDrive\Dokumenter\NTNU\Riflex_run\Inputfile\STRAKES2\Experiment\Trajectories')
    %% Plot cross section displacement trajectories 
    figure
    plot(Ax2(1,:), Ay2(1,:), Ax2(4,:), Ay2(4,:), Ax2(8,:), Ay2(8,:)) 
    legend('Sensor 5', 'Sensor 19', 'Sensor 36') 
    xlabel('X (m)')
    ylabel('Y (m)') 
    saveas(gcf, ['disptrajectories' testnrr '.png'])
    saveas(gcf, ['disptrajectories' testnrr])
    
    
    
    %% Filtering Bending Strain Time History
    %CF
    bp1 = bpass(S_data',dt,hpCF,hlpCF);
    S_data1=bp1';                      %bpass strain signal to get the total strain signal
    bp2 = bpass(S_data',dt,hpCF,lpCF);
    S_data2=bp2';                      %bpass strain signal to get the strain signal at 1xw frequency component
    bp3=bpass(S_data',dt,hhpCF,hlpCF);
    S_data3=bp3';                      %bpass strain signal to get the strain signal at 3xw frequency component
    
    %IL 
    bp4 = bpass(N_data',dt,hpIL,hlpIL);
    N_data1=bp4';                      %bpass strain signal to get the total strain signal
    bp5 = bpass(N_data',dt,hpIL,lpIL);
    N_data2=bp5';                      %bpass strain signal to get the strain signal at 2xw frequency component
    bp6=bpass(N_data',dt,hhpIL,hlpIL);
    N_data3=bp6';                      %bpass strain signal to get the strain signal at 4xw frequency component
    
    
        %% Plot cross section strain trajectories 
    figure
    plot(N_data2(5,:), S_data2(4,:), N_data2(19,:), S_data2(11,:), N_data2(36,:), S_data2(22,:)) 
    legend('Sensor 5', 'Sensor 19', 'Sensor 36') 
    xlabel('In-line (\mu m/m)')
    ylabel('Cross-flow (\mu m/m)') 
    saveas(gcf, ['straintrajectories' testnrr '.png'])
    saveas(gcf, ['straintrajectories' testnrr])
    
    
    
    %% Calculate spectrum
    %IL strain and displacement spectrum at sensor 19 (16.891m), sensor 5 (4.155m) and
    %sensor 36 (33.005m)
    [SpcILs5,fIL5,NhiIL5]=spec(N_data2(5,:),nt,Fs);    
    [SpcILs19,fIL19,NhiIL19]=spec(N_data2(19,:),nt,Fs); 
    [SpcILs36,fIL36,NhiIL36]=spec(N_data2(36,:),nt,Fs);
    [SpcILd19,fdIL19,NhidIL19]=spec(Ax2(4,:),nt,Fs); 
    [SpcILd5,fdIL5,NhidIL5]=spec(Ax2(1,:),nt,Fs);
    [SpcILd36,fdIL36,NhidIL36]=spec(Ax2(8,:),nt,Fs);
    
    %CF strain and displacement spectrum at sensor 19 (16.891m), sensor 5 (4.155m) and
    %sensor 36 (33.005m). Note: fewer CF strains sensors. Sensor 19 is not the 19th
    %CF sensor!
    [SpcCFs5,fCF5,NhiCF5]=spec(S_data2(4,:),nt,Fs);    
    [SpcCFs19,fCF19,NhiCF19]=spec(S_data2(11,:),nt,Fs); 
    [SpcCFs36,fCF36,NhiCF36]=spec(S_data2(22,:),nt,Fs);
    [SpcCFd5,fdCF5,NhidCF5]=spec(Ay2(1,:),nt,Fs);
    [SpcCFd19,fdCF19,NhidCF19]=spec(Ay2(4,:),nt,Fs); 
    [SpcCFd36,fdCF36,NhidCF36]=spec(Ay2(8,:),nt,Fs);
    
    %Consider three envelops in time: first 1/3, second 1/3 and last 1/3 of
    %time series
    [SpcILs5_1,fIL5_1,NhiIL5_1]=spec(N_data2(5,1:length(time)/3),nt,Fs);
    [SpcILs5_2,fIL5_2,NhiIL5_2]=spec(N_data2(5,length(time)/3+1:2*length(time)/3),nt,Fs);
    [SpcILs5_3,fIL5_3,NhiIL5_3]=spec(N_data2(5,2*length(time)/3+1:length(time)),nt,Fs);
    [SpcCFs5_1,fCF5_1,NhiCF5_1]=spec(S_data2(4,1:length(time)/3),nt,Fs);
    [SpcCFs5_2,fCF5_2,NhiCF5_2]=spec(S_data2(4,length(time)/3+1:2*length(time)/3),nt,Fs);
    [SpcCFs5_3,fCF5_3,NhiCF5_3]=spec(S_data2(4,2*length(time)/3+1:length(time)),nt,Fs);
    
    
    %Find maxima, with associated frequency, of spectra
    [valueILs5, indILs5]=max(SpcILs5);
    [valueCFs5, indCFs5]=max(SpcCFs5);
    [valueILs19, indILs19]=max(SpcILs19);
    [valueCFs19, indCFs19]=max(SpcCFs19);
    [valueILs36, indILs36]=max(SpcILs36);
    [valueCFs36, indCFs36]=max(SpcCFs36);
    [valueILd5, indILd5]=max(SpcILd5);
    [valueCFd5, indCFd5]=max(SpcCFd5);
    [valueILd19, indILd19]=max(SpcILd19);
    [valueCFd19, indCFd19]=max(SpcCFd19);
    [valueILd36, indILd36]=max(SpcILd36);
    [valueCFd36, indCFd36]=max(SpcCFd36);
    %Find the peak frequency
    fdomsCF(ic,1)=fCF5(indCFs5); %Find dominating frequencies CF of strain
    fdomsCF(ic,2)=fCF19(indCFs19); 
    fdomsCF(ic,3)=fCF36(indCFs36); 
    fdomsIL(ic,1)=fIL5(indILs5); %Find dominating frequencies IL of strain
    fdomsIL(ic,2)=fIL19(indILs19); 
    fdomsIL(ic,3)=fIL36(indILs36); 
    fdomdCF(ic,1)=fdCF5(indCFd5); %Find dominating frequencies CF of displacement
    fdomdCF(ic,2)=fdCF19(indCFd19); 
    fdomdCF(ic,3)=fdCF36(indCFd36); 
    fdomdIL(ic,1)=fdIL5(indILd5); %Find dominating frequencies IL of displacement
    fdomdIL(ic,2)=fdIL19(indILd19); 
    fdomdIL(ic,3)=fdIL36(indILd36); 
    
  
    %Set directory for plots
    cd(['C:\Users\dreng\OneDrive\Dokumenter\NTNU\Riflex_run\Inputfile\STRAKES2\Experiment\Spectra\Bandpassed(fs8)'])
    %Plot strain spectrum
    figure 
    subplot(2,1,1)
    plot( fIL5(1:NhiIL5),SpcILs5(1:NhiIL5),fIL19(1:NhiIL19),SpcILs19(1:NhiIL19), fIL36(1:NhiIL36),SpcILs36(1:NhiIL36))
    xlim([0 30])
    ylabel('Microstrain spectrum (s)')
    xlabel('Frequency (Hz)')
    grid on
    legend('Sensor 5', 'Sensor 19', 'Sensor 36') 
    title('In-line')
    subplot(2,1,2)
    plot(fCF5(1:NhiCF5),SpcCFs5(1:NhiCF5),fCF19(1:NhiCF19),SpcCFs19(1:NhiCF19), fCF36(1:NhiCF36),SpcCFs36(1:NhiCF36))
    xlim([0 30])
    ylabel('Microstrain spectrum (s)')
    xlabel('Frequency (Hz)')
    grid on
    legend('Sensor 5', 'Sensor 19', 'Sensor 36') 
    title('Cross-flow')
    saveas(gcf,['strainspec' testnrr], 'epsc');
    saveas(gcf,['strainspec' testnrr '.png'])
    
    %Plot strain spectrum at sensor 5
    figure 
%     subplot(2,1,1)
%     plot( fIL5(1:NhiIL5),SpcILs5(1:NhiIL5))
%     xlim([0 10])
%     ylabel('Microstrain spectrum (s)')
%     xlabel('Frequency (Hz)')
%     grid on
%     legend('Sensor 5') 
%     title('In-line')
%     subplot(2,1,2)
    plot(fCF5(1:NhiCF5),SpcCFs5(1:NhiCF5))
    xlim([0 10])
    ylabel('Microstrain spectrum (s)')
    xlabel('Frequency (Hz)')
    grid on
    %legend('Sensor 5') 
    title('Cross-flow')
    saveas(gcf,['strainspec5' testnrr], 'epsc');
    saveas(gcf,['strainspec5' testnrr '.png'])
    
    %Plot strain spectrum at sensor 5, three intervals
    figure 
%     subplot(2,1,1)
%     plot( fIL5_1(1:NhiIL5_1),SpcILs5_1(1:NhiIL5_1), fIL5_2(1:NhiIL5_2),SpcILs5_2(1:NhiIL5_2), fIL5_3(1:NhiIL5_3),SpcILs5_3(1:NhiIL5_3))
%     xlim([0 15])
%     ylabel('Microstrain spectrum (s)')
%     xlabel('Frequency (Hz)')
%     grid on
%     legend('Inteval 1', 'Interval 2', 'Interval 3') 
%     title('In-line')
%     subplot(2,1,2)
    plot(fCF5_1(1:NhiCF5_1),SpcCFs5_1(1:NhiCF5_1), fCF5_2(1:NhiCF5_2),SpcCFs5_2(1:NhiCF5_2), fCF5_3(1:NhiCF5_3),SpcCFs5_3(1:NhiCF5_3))
    xlim([0 15])
    ylabel('Microstrain spectrum (s)')
    xlabel('Frequency (Hz)')
    grid on
    legend('Inteval 1', 'Interval 2', 'Interval 3') 
    title('Cross-flow')
    saveas(gcf,['strainspec5env' testnrr], 'epsc');
    saveas(gcf,['strainspec5env' testnrr '.png'])
    
    %plot displacement spectrum
    figure 
    subplot(2,1,1)
    plot( fdIL5(1:NhidIL5),SpcILd5(1:NhidIL5),fdIL19(1:NhidIL19),SpcILd19(1:NhidIL19), fdIL36(1:NhidIL36),SpcILd36(1:NhidIL36))
    xlim([0 30])
    ylabel('Disp. spectrum (m^{2}s)')
    xlabel('Frequency (Hz)')
    grid on
    legend('Sensor 5', 'Sensor 19', 'Sensor 36') 
    title('In-line')
    subplot(2,1,2)
    plot(fdCF5(1:NhidCF5),SpcCFd5(1:NhidCF5),fdCF19(1:NhidCF19),SpcCFd19(1:NhidCF19), fdCF36(1:NhidCF36),SpcCFd36(1:NhidCF36))
    xlim([0 30])
    ylabel('Disp. spectrum (m^{2}s)')
    xlabel('Frequency (Hz)')
    grid on
    legend('Sensor 5', 'Sensor 19', 'Sensor 36') 
    title('Cross-flow')
    saveas(gcf,['dispspecband' testnrr], 'epsc');
    saveas(gcf,['dispspecband' testnrr '.png']);
    
    
    %Plot displacement spectrum only at sensor 19 
    figure
    subplot(2,1,1) 
    plot(fdIL19(1:NhidIL19),SpcILd19(1:NhidIL19)) 
    xlim([0 30])
    ylabel('Disp. power spectrum (m^{2}s)')
    xlabel('Frequency (Hz)')
    grid on
    legend( 'Sensor 19') 
    title('In-line')
    subplot(2,1,2)
    plot(fdCF19(1:NhidCF19),SpcCFd19(1:NhidCF19)) 
    xlim([0 30])
    ylabel('Disp. power spectrum (m^{2}s)')
    xlabel('Frequency (Hz)')
    grid on
    legend( 'Sensor 19') 
    title('Cross-flow')
    saveas(gcf,['dispspec19band' testnrr]);
    saveas(gcf,['dispspec19band' testnrr '.png']);
    
     %Plot displacement spectrum only at sensor 36 
    figure
    subplot(2,1,1) 
    plot(fdIL36(1:NhidIL36),SpcILd36(1:NhidIL36)) 
    xlim([0 30])
    ylabel('Disp. power spectrum (m^{2}s)')
    xlabel('Frequency (Hz)')
    grid on
    legend( 'Sensor 36') 
    title('In-line')
    subplot(2,1,2)
    plot(fdCF36(1:NhidCF36),SpcCFd36(1:NhidCF36)) 
    xlim([0 30])
    ylabel('Disp. power spectrum (m^{2}s)')
    xlabel('Frequency (Hz)')
    grid on
    legend( 'Sensor 36') 
    title('Cross-flow')
    saveas(gcf,['dispspec36band' testnrr]);
    saveas(gcf,['dispspec36band' testnrr '.png']);
    
    %% SN curve parameters
    m0=3;                            
    K0=10^(-11.63);

    
    %% Bending stress
    %CF
    SsCF=S_data1.*E.*1e-12;             %the total stress
    stdSsCF(ic,:)=std(SsCF');
   
    
    SsCF2=S_data2.*E.*1e-12;            %the 1w stress
    SsCF2m=SsCF2-mean(SsCF2); 
    stdSsCF2(ic,:)=std(SsCF2');
    stdSsCF2m(ic,:)=std(SsCF2m'); 
    
    SsCF3=S_data3.*E.*1e-12;            %the 3w stress
    stdSsCF3(ic,:)=std(SsCF3');
    
    
    %IL
    SsIL=N_data1.*E.*1e-12;
    stdSsIL(ic,:)=std(SsIL'); 
    
    SsIL2=N_data2.*E.*1e-12;            
    stdSsIL2(ic,:)=std(SsIL2');
    
    SsIL3=N_data3.*E.*1e-12;            
    stdSsIL3(ic,:)=std(SsIL3');
    
[maxSTDstressIL, indstressIL] = max(stdSsIL2(ic,30:end)); %Find position of max in-line curvature
[maxSTDstressCF, indstressCF] = max(stdSsCF2(ic,19:end)); %Find position of max cross-flow curvature

    %Find the stress spectrum at the position of max stress response 
    [SpcIL,fILmax,NhiILmax]=spec(SsIL2(indstressIL+29,:),nt,Fs);
    [SpcCF,fCFmax,NhiCFmax]=spec(SsCF2(indstressCF+18,:),nt,Fs);
    %Plot stress spectra 
    figure 
    subplot(2,1,1)
    plot( fILmax(1:NhiILmax),SpcIL(1:NhiILmax))
    xlim([0 30])
    ylabel('IL stress')
    xlabel('Frequency (Hz)')
    grid on
    legend(['Sensor' num2str(indstressIL+29)]) 
    title(['Filtered IL stress' testnrr])
    subplot(2,1,2)
    plot(fCFmax(1:NhiCFmax),SpcCF(1:NhiCFmax))
    xlim([0 30])
    ylabel('CF stress')
    xlabel('Frequency (Hz)')
    grid on
    legend(['Sensor' num2str(indstressCF+18)]) 
    title(['Filtered CF stress' testnrr])
    saveas(gcf,['stressspecmax' testnrr]);
    saveas(gcf,['stressspecmax' testnrr '.png']);    
    %Find the stress spectra peak frequencies at the position of max response
    [maxSpecStressIL, indspecIL] = max(SpcIL); 
    [maxSpecStressCF, indspecCF] = max(SpcCF); 
    fdomsIL(ic,4) = fILmax(indspecIL);
    fdomsCF(ic,4) =  fCFmax(indspecCF);
    
    %%  Fatigue calculation
    %CF
    [p,q]=size(SsCF);
    for i=1:p
        Ss_tpCF=dat2tp(SsCF(i,:));
        Ss_tpCF2=dat2tp(SsCF2(i,:));
        Ss_tpCF3=dat2tp(SsCF3(i,:));
        Ss_rfcCF=tp2rfc(Ss_tpCF);
        Ss_rfcCF2=tp2rfc(Ss_tpCF2);
        Ss_rfcCF3=tp2rfc(Ss_tpCF3);
        fs_rfcfdCF(ic,i)=cc2dam(Ss_rfcCF,m0,K0)*2^m0/(nt*dt)*3600*24*365;    % fatigue damage of the total signal (1w-3w)
        fs_rfcfd2CF(ic,i)=cc2dam(Ss_rfcCF2,m0,K0)*2^m0/(nt*dt)*3600*24*365;  % fatigue damage of the 1xw frequency component
        fs_rfcfd3CF(ic,i)=cc2dam(Ss_rfcCF3,m0,K0)*2^m0/(nt*dt)*3600*24*365;  % fatigue damage of the 3xw frequency component
    end
    
 
    %IL
    [p,q]=size(SsIL);
    for i=1:p
        Ss_tpIL=dat2tp(SsIL(i,:));
        Ss_tpIL2=dat2tp(SsIL2(i,:));
        Ss_tpIL3=dat2tp(SsIL3(i,:));
        Ss_rfcIL=tp2rfc(Ss_tpIL);
        Ss_rfcIL2=tp2rfc(Ss_tpIL2);
        Ss_rfcIL3=tp2rfc(Ss_tpIL3);
        fs_rfcfdIL(ic,i)=cc2dam(Ss_rfcIL,m0,K0)*2^m0/(nt*dt)*3600*24*365;    % fatigue damage of the total signal (2w-4w)
        fs_rfcfdIL2(ic,i)=cc2dam(Ss_rfcIL2,m0,K0)*2^m0/(nt*dt)*3600*24*365;  % fatigue damage of the 2xw frequency component
        fs_rfcfdIL3(ic,i)=cc2dam(Ss_rfcIL3,m0,K0)*2^m0/(nt*dt)*3600*24*365;  % fatigue damage of the 4xw frequency component
    end
    
    
end

%Replace data from CF strain gauge 21 with mean of neighbours
stdSsCF(1:22,21)=(stdSsCF(1:22,20)+stdSsCF(1:22,22))/2; 
stdSsCF2(1:22,21)=(stdSsCF2(1:22,20)+stdSsCF2(1:22,22))/2; 
stdSsCF3(1:22,21)=(stdSsCF3(1:22,20)+stdSsCF3(1:22,22))/2; 
fs_rfcfdCF(1:22,21)=(fs_rfcfdCF(1:22,20)+fs_rfcfdCF(1:22,22))/2; 
fs_rfcfd2CF(1:22,21)=(fs_rfcfd2CF(1:22,20)+fs_rfcfd2CF(1:22,22))/2; 
fs_rfcfd3CF(1:22,21)=(fs_rfcfd3CF(1:22,20)+fs_rfcfd3CF(1:22,22))/2; 

save('C:\Users\dreng\OneDrive\Dokumenter\NTNU\Riflex_run\High Mode VIV Model tests\Raw data\straked2measdata1w.mat')
    

% figure
% plot(time, A,'-k',time,A2,'-b',time,A3,'-m')