
%%This script computes the stresses and fatigue from the strains and
%%integrate the accelerations to displacements for the NDP experimental
%%data with bare risers. 

clear all
close all

%Calculate the fatigue damage for 44 bare NDP cases

Fs=1200;    %Sampling frequency
dt=1/Fs;

Do=0.027;   %Outer diameter
E=36.2e9;   %Elastic modulus

load icasesd2.txt -ascii            %Cases and timewindow defined
ncases = length(icasesd2(:,1));      %Number of cases
U = 0.3:0.1:2.4;
U(23:44)=U;
%%
for ic = 1:44 % Start loop over number of cases

    %% load data
    str_icase = int2str(icasesd2(ic,1));
    testnrr = [str_icase]                %Name of case
    testnr = ['test',str_icase,'.mat'];  %From mat file
    eval(['load ',testnr ]);             %Load model test results
    
    
    t1 = icasesd2(ic,2);   %Start analysis at time given in icasesd2.txt
    t2 = icasesd2(ic,3);   %End analysis at time given in icasesd2.txt
    
    %Strouhal frequency
    S=0.17;
    f_disp = U(ic)*S/Do/3;
    %CF cut-off frequencies
    %hp-lp: filtering bandwidth of the 1xw frequency component  From fdisp to 1.5/2xw
    if f_disp<0.75
        hpCF = 0.75; 
    else
    hpCF = f_disp;
    end
    lpCF = icasesd2(ic,5); % lp Hz, 1.5xw
    %hhp-hlp: filtering bandwidth of the 3xw frequency component
    hhpCF = icasesd2(ic,6);  % hhp Hz,
    hlpCF = icasesd2(ic,7);  % hlp. From 2.5xw to 3.5xw

    %IL cut-off frequencies
    %hp-lp: filtering bandwidth of the 2xw frequency component from
    %2*f_disp to 2.5xw
    hpIL = f_disp*2; 
    lpIL = icasesd2(ic,6); % lp Hz, 2.5xw
    %hp-lp: filtering bandwidth of the 4xw frequency component
    hhpIL = icasesd2(ic,7); % hp Hz
    hlpIL = 9*icasesd2(ic,4); % lp. From 3.5xw to 4.5xw
    
    % % Analysis time window
    tst=t1*Fs;
    ted=t2*Fs;
    %     nt=ted-tst+1;
    
    % load CF strain data
    S_data= double(data(47:70,:));  %24 channels of the CF strain signal
    
    % load CF acc data
    ay_data= double(data(79:86,:));  % Measured CF acceleration signals from channel 79-86
    
    % load IL strain data
    N_data= double(data(7:46,:));  %40 channels of the IL strain signal

    % load IL acc data    
    ax_data= double(data(71:78,:));  % Measured IL acceleration signals from channel 71-78
    

    %Load riser effective tension 
    eff_tens=double(data(119,:)); %Measured force in y-dir at riser bottom from channel 88 
    
    nm = length(S_data);              % Number of measurement time steps
    time = [0:nm-1]*dt;               % Time (sec)
    nt = (t2-t1)*Fs;                  % Number of selected time steps
    nst = t1*Fs;                      % Start time step
    
    S_data(:,1:nst)=[];
    S_data(:,nt+1:nm-nst)=[];      %S_data
    
    ay_data(:,1:nst)=[];            % Select data from nst+1:nst+nt
    ay_data(:,nt+1:nm-nst)=[];
    
    N_data(:,1:nst)=[];
    N_data(:,nt+1:nm-nst)=[];
    
    eff_tens(:,1:nst)=[]; 
    eff_tens(:,nt+1:nm-nst)=[]; 
    
    ax_data(:,1:nst)=[];            
    ax_data(:,nt+1:nm-nst)=[];
    
    time(:,1:nst)=[];
    time(:,nt+1:nm-nst)=[];
    
    
    %% calculate CF and IL displacement
    [c,k]=size(ay_data);
    
    for i=1:c
        ay=ay_data(i,:);
        Ay=acc2displ(ay,Fs,hpCF,hlpCF); %1w to 3w
        Ay2=acc2displ(ay,Fs,hpCF,lpCF); %Only 1w
        Ay3=acc2displ(ay,Fs,hhpCF,hlpCF); %Only 3w
        ADy(ic,i)=std(Ay)/Do;
        ADy2(ic,i)=std(Ay2)/Do;
        ADy3(ic,i)=std(Ay3)/Do;
    end
    
    [c,k]=size(ax_data);
    
    for i=1:c
        ax=ax_data(i,:);
        Ax=acc2displ(ax,Fs,hpIL,hlpIL); %1w to 3w
        Ax2=acc2displ(ax,Fs,hpIL,lpIL); %1w
        Ax3=acc2displ(ax,Fs,hhpIL,hlpIL); %3w
        ADx(ic,i)=std(Ax)/Do;
        ADx2(ic,i)=std(Ax2)/Do;
        ADx3(ic,i)=std(Ax3)/Do;
    end
    
    
    %% Filtering Bending Strain Time History
    %CF
    bp1 = bpass(S_data',dt,hpCF,hlpCF);
    S_data1=bp1';                      %bpass strain signal to get the total strain signal
    bp2 = bpass(S_data',dt,hpCF,lpCF);
    S_data2=bp2';                      %bpass strain signal to get the strain signal at 1xw frequency component
    bp3=bpass(S_data',dt,hhpCF,hlpCF);
    S_data3=bp3';                      %bpass strain signal to get the strain signal at 3xw frequency component
    
    %IL 
    bp4 = bpass(N_data',dt,hpIL,hlpIL);
    N_data1=bp4';                      %bpass strain signal to get the total strain signal
    bp5 = bpass(N_data',dt,hpIL,lpIL);
    N_data2=bp5';                      %bpass strain signal to get the strain signal at 2xw frequency component
    bp6=bpass(N_data',dt,hhpIL,hlpIL);
    N_data3=bp6';                      %bpass strain signal to get the strain signal at 4xw frequency component
    
    
    %set directory for storing trajectories
    cd('C:\Users\dreng\OneDrive\Dokumenter\NTNU\Riflex_run\Inputfile\BARE\Experiments\Trajectories')
    %% Plot cross section strain trajectories 
    figure
    plot(N_data2(5,:), S_data2(4,:), N_data2(19,:), S_data2(11,:), N_data2(36,:), S_data2(22,:)) 
    legend('Sensor 5', 'Sensor 19', 'Sensor 36') 
    xlabel('In-line (\mu m/m)')
    ylabel('Cross-flow (\mu m/m)') 
    saveas(gcf, ['straintrajectories' testnrr '.png'])
    saveas(gcf, ['straintrajectories' testnrr])
    
    
    
      %% Calculate spectrum
    %IL strain spectrum at sensor 19 (16.891m), sensor 5 (4.155m) and
    %sensor 36 (33.005m)
    [SpcILs19,f19,Nhi19]=spec(N_data2(19,:),nt,Fs); 
    [SpcILs5,f5,Nhi5]=spec(N_data2(5,:),nt,Fs);
    [SpcILs36,f36,Nhi36]=spec(N_data2(36,:),nt,Fs);
    %CF strain spectrum at sensor 19 (16.891m), sensor 5 (4.155m) and
    %sensor 36 (33.005m). Note: fewer CF sensors. Sensor 19 is not the 19th
    %CF sensor!
    [SpcCFs19,f19,Nhi19]=spec(S_data2(11,:),nt,Fs); 
    [SpcCFs5,f5,Nhi5]=spec(S_data2(4,:),nt,Fs);
    [SpcCFs36,f36,Nhi36]=spec(S_data2(22,:),nt,Fs);
    [valueIL5, indx5]=max(SpcILs5);
    [valueCF5, indz5]=max(SpcCFs5);
    [valueIL19, indx19]=max(SpcILs19);
    [valueCF19, indz19]=max(SpcCFs19);
    [valueIL36, indx36]=max(SpcILs36);
    [valueCF36, indz36]=max(SpcCFs36);
    fdomCF(ic,1)=f5(indz5); %Find dominating frequencies CF
    fdomCF(ic,2)=f19(indz19); 
    fdomCF(ic,3)=f36(indz36); 
    fdomIL(ic,1)=f5(indx5); %Find dominating frequencies CF
    fdomIL(ic,2)=f19(indx19); 
    fdomIL(ic,3)=f36(indx36); 
      
    cd(['C:\Users\dreng\OneDrive\Dokumenter\NTNU\Riflex_run\Inputfile\BARE\Experiments\Spectra'])
    figure 
    subplot(2,1,1)
    plot( f5(1:Nhi5),SpcILs5(1:Nhi5),f19(1:Nhi19),SpcILs19(1:Nhi19), f36(1:Nhi36),SpcILs36(1:Nhi36))
    xlim([0 30])
    ylabel('IL strain')
    xlabel('Frequency (Hz)')
    grid on
    legend('Sensor 5', 'Sensor 19', 'Sensor 36') 
    title(['Filtered IL strain' testnrr])
    subplot(2,1,2)
    plot(f5(1:Nhi5),SpcCFs5(1:Nhi5),f19(1:Nhi19),SpcCFs19(1:Nhi19), f36(1:Nhi36),SpcCFs36(1:Nhi36))
    xlim([0 30])
    ylabel('CF strain')
    xlabel('Frequency (Hz)')
    grid on
    legend('Sensor 5', 'Sensor 19', 'Sensor 36') 
    title(['Filtered CF strain' testnrr])
    saveas(gcf,['strainspec' testnrr '.png']);
    
    %% SN curve parameters
    m0=3;                            % old SN curve
    K0=10^(-11.63);
    
    %% Bending stress
    %CF
    SsCF=S_data1.*E.*1e-12;             %the total stress
    stdSsCF(ic,:)=std(SsCF');
    
    SsCF2=S_data2.*E.*1e-12;            %the 1w stress
    stdSsCF2(ic,:)=std(SsCF2');
    
    SsCF3=S_data3.*E.*1e-12;            %the 3w stress
    stdSsCF3(ic,:)=std(SsCF3');
    
    
    %IL
    SsIL=N_data1.*E.*1e-12;
    stdSsIL(ic,:)=std(SsIL'); 
    
    SsIL2=N_data2.*E.*1e-12;            
    stdSsIL2(ic,:)=std(SsIL2');
    
    SsIL3=N_data3.*E.*1e-12;            
    stdSsIL3(ic,:)=std(SsIL3');
    
    
[maxSTDstressIL, indstressIL] = max(stdSsIL2(ic,:)); %Find position of max in-line curvature
[maxSTDstressCF, indstressCF] = max(stdSsCF2(ic,:)); %Find position of max cross-flow curvature

    %Find the stress spectrum at the position of max stress response 
    [SpcIL,fILmax,NhiILmax]=spec(SsIL2(indstressIL,:),nt,Fs);
    [SpcCF,fCFmax,NhiCFmax]=spec(SsCF2(indstressCF,:),nt,Fs);
    %Plot stress spectra 
    figure 
    subplot(2,1,1)
    plot( fILmax(1:NhiILmax),SpcIL(1:NhiILmax))
    xlim([0 30])
    ylabel('IL stress')
    xlabel('Frequency (Hz)')
    grid on
    legend(['Sensor' num2str(indstressIL)]) 
    title(['Filtered IL stress' testnrr])
    subplot(2,1,2)
    plot(fCFmax(1:NhiCFmax),SpcCF(1:NhiCFmax))
    xlim([0 30])
    ylabel('CF stress')
    xlabel('Frequency (Hz)')
    grid on
    legend(['Sensor' num2str(indstressCF)]) 
    title(['Filtered CF stress' testnrr])
    saveas(gcf,['stressspecmax' testnrr]);
    saveas(gcf,['stressspecmax' testnrr '.png']);    
    %Find the stress spectra peak frequencies at the position of max response
    [maxSpecStressIL, indspecIL] = max(SpcIL); 
    [maxSpecStressCF, indspecCF] = max(SpcCF); 
    fdomsIL(ic,4) = fILmax(indspecIL);
    fdomsCF(ic,4) =  fCFmax(indspecCF);    


    %%  Fatigue calculation
    %CF
    [p,q]=size(SsCF);
    for i=1:p
        Ss_tpCF=dat2tp(SsCF(i,:));
        Ss_tpCF2=dat2tp(SsCF2(i,:));
        Ss_tpCF3=dat2tp(SsCF3(i,:));
        Ss_rfcCF=tp2rfc(Ss_tpCF);
        Ss_rfcCF2=tp2rfc(Ss_tpCF2);
        Ss_rfcCF3=tp2rfc(Ss_tpCF3);
        fs_rfcfdCF(ic,i)=cc2dam(Ss_rfcCF,m0,K0)*2^m0/(nt*dt)*3600*24*365;    % fatigue damage of the total signal (1w-3w)
        fs_rfcfd2CF(ic,i)=cc2dam(Ss_rfcCF2,m0,K0)*2^m0/(nt*dt)*3600*24*365;  % fatigue damage of the 1xw frequency component
        fs_rfcfd3CF(ic,i)=cc2dam(Ss_rfcCF3,m0,K0)*2^m0/(nt*dt)*3600*24*365;  % fatigue damage of the 3xw frequency component
    end
    
 
    %IL
    [p,q]=size(SsIL);
    for i=1:p
        Ss_tpIL=dat2tp(SsIL(i,:));
        Ss_tpIL2=dat2tp(SsIL2(i,:));
        Ss_tpIL3=dat2tp(SsIL3(i,:));
        Ss_rfcIL=tp2rfc(Ss_tpIL);
        Ss_rfcIL2=tp2rfc(Ss_tpIL2);
        Ss_rfcIL3=tp2rfc(Ss_tpIL3);
        fs_rfcfdIL(ic,i)=cc2dam(Ss_rfcIL,m0,K0)*2^m0/(nt*dt)*3600*24*365;    % fatigue damage of the total signal (2w-4w)
        fs_rfcfdIL2(ic,i)=cc2dam(Ss_rfcIL2,m0,K0)*2^m0/(nt*dt)*3600*24*365;  % fatigue damage of the 2xw frequency component
        fs_rfcfdIL3(ic,i)=cc2dam(Ss_rfcIL3,m0,K0)*2^m0/(nt*dt)*3600*24*365;  % fatigue damage of the 4xw frequency component
    end
    
    

end

%Replace data from CF strain gauge 21 with mean of neighbours
stdSsCF(12:17,21)=(stdSsCF(12:17,20)+stdSsCF(12:17,22))/2; 
stdSsCF2(12:17,21)=(stdSsCF2(12:17,20)+stdSsCF2(12:17,22))/2; 
stdSsCF3(12:17,21)=(stdSsCF3(12:17,20)+stdSsCF3(12:17,22))/2; 
fs_rfcfdCF(12:17,21)=(fs_rfcfdCF(12:17,20)+fs_rfcfdCF(12:17,22))/2; 
fs_rfcfd2CF(12:17,21)=(fs_rfcfd2CF(12:17,20)+fs_rfcfd2CF(12:17,22))/2; 
fs_rfcfd3CF(12:17,21)=(fs_rfcfd3CF(12:17,20)+fs_rfcfd3CF(12:17,22))/2; 

save('C:\Users\dreng\OneDrive\Dokumenter\NTNU\Riflex_run\High Mode VIV Model tests\Raw data\nakedmeasdata1w.mat')
    

% figure
% plot(time, A,'-k',time,A2,'-b',time,A3,'-m')