function x = acc2displ(a, Fs, hp, lp)

 

%***********************************************************************

%Function calculating the displacement time series from an acceleration time

%series, integration in frequency domain. Band-pass filtering included

%

%   x = acc2displ(a, Fs, hp, lp)

%

%   a = acceleration time series, vector

%   Fs = sampling frequency

%   hp = high pass cut frequency

%   lp = low pass cut frequency

%

%

% Aron April 2005

%***********************************************************************

 

pi=4*atan(1);

if length(a)==1,error('a contains only one element'),end

if nargin~=4,error('Wrong number of arguments'),end

 

[m0,n0] = size(a);

 

if m0==1,    

   a = a';                              % If a vector, make x a column vector

   m = n0;

   n = m0;

else

   m = m0;  

   n = n0;                            

end

 

domega = 2*pi*Fs/m;

A = i*zeros(m,1);          % Initialize complex matrix

A = fft(a);                              % Discrete frequency transformation

omega = zeros(m,1);

 

if floor(m/2)==ceil(m/2)

    mh=m/2;

    omega(1:mh+1)=domega*(0:mh);

    omega(mh+2:m)=domega*(-mh+1:-1);

else

    mh=(m-1)/2;

    omega(1:mh+1)=domega*(0:mh);

    omega(mh+2:m)=domega*(-mh:-1);

end

 

df = Fs/(m);                             % Frequency interval

mcut1 = round(hp/df);                    % Number of points to zero out at each end

mcut2 = round(lp/df);                    % Number of points to zero out

A(1:1+mcut1) = 0.;                     % Zero out positive frequencies

ntest = m/2 -1;

if (mcut2 < ntest)

  A(1+mcut2:m-mcut2+1) = 0.;

end

A(m-mcut1+1:m) = 0.;                   %%% - and negative frequencies

 

X(1)=0.0;

X(2:length(A)-1)=A(2:length(A)-1)./(omega(2:length(A)-1).*i).^2;

X(length(A))=0.0;

 

x = real(ifft(X))';                   % Back to time domain, displacement

