% readTimeDomainResults  Reads in results from a single simulation 
% 

close all
clear all
clc
n= 12;
Mean_rotor_speed = zeros(1,n);
Mean_thrust= zeros(1,n);
Mean_torque=zeros(1,n);
Mean_power = zeros(1,n);
Mean_blade_pitch= zeros(1,n);
Mean_platform_surge = zeros(1,n);
Mean_platform_pitch = zeros(1,n); 



%% User-defined input
for i = 1:n
windno = num2str(i);    
folder = strcat('C:\Users\dreng\OneDrive\Dokumenter\NTNU\Hst 2018\Integrated dynamic analysis of wind turbines\SIMA\CSC5MW\conditionSet\conditionSet_',windno);
prefix = 'sima';
hullBody = 1; % typically 1 

%% READ SIMULATION OUTPUT
%==========================================================================
%%READ SIMULATION OUTPUT
    % Read the SIMO results text file to get the channel names and number
    % of steps
    [nchan, nts, dt, chanNames] = readSIMO_resultstext([folder '\results.txt']);
    % Read the binary file
    BB = read_simoresults([folder '\results.tda'],nts);
    sizeBB = size(BB);
    if (sizeBB(1)<nts || nts<1); disp('Unable to read SIMO results'); return; end;
    % Determine which channels to read for the platform motions, wave
    % elevation
    [chanMotions, chanWave] = getchannelNumbers(chanNames,hullBody);
    if (chanMotions(1)<1 || chanWave<1); disp('Unable to read SIMO results'); return; end;
    time_SIMO = BB(:,2);
    
    % summarize data in matrix
    PlatMotions = BB(:,chanMotions);
    SurgeMotions = PlatMotions(:,1);
    PitchMotions = PlatMotions(:,5);
    wave = BB(:,chanWave);

    % Read the wind turbine results 
    fname = [folder '\' prefix '_witurb.bin'];
    BB = read_rifbin(fname,0,26);
    sizeBB = size(BB);
    Nt = sizeBB(1); % get the number of time steps
    if Nt<2; disp('Unable to read RIFLEX wind turbine results'); return; end; 
    
    time_RIFLEX = BB(:,2);
    omega = BB(:,3)*pi/180; % convert from deg/s to rad/s
    genTq = BB(:,5); 
    genPwr = BB(:,6)*94.4/100; % generator efficiency included
    azimuth = BB(:,7); 
    HubWindX = BB(:,8);
    HubWindY = BB(:,9);
    HubWindZ = BB(:,10);
    AeroForceX = BB(:,11);
    AeroMomX = BB(:,14);
    Bl1Pitch = BB(:,17);
    Bl2Pitch = BB(:,18);
    Bl3Pitch = BB(:,19); 

    % Read the RIFLEX force output file
    fname = [folder '\' prefix '_elmfor.bin'];
    BB = read_rifbin(fname,Nt);
    sizeBB = size(BB);
    if(sizeBB(1)<Nt); disp('Unable to read RIFLEX force results'); return; end;  

    % Tower Base
    TowerBaseAxial  = BB(:,3);
    TowerBaseTors   = BB(:,4);
    TowerBaseBMY    = BB(:,5);
    TowerBaseBMZ    = BB(:,7);
    TowerBaseShearY = BB(:,9);
    TowerBaseShearZ = BB(:,11);

    % Tower Top
    TowerTopAxial  = BB(:,13);
    TowerTopTors   = BB(:,14);
    TowerTopBMY    = BB(:,16); % end 2
    TowerTopBMZ    = BB(:,18);
    TowerTopShearY = BB(:,20);
    TowerTopShearZ = BB(:,22);    
    
    % Blade 1
    bl1Axial        = BB(:,23);
    bl1Tors         = BB(:,24);
    bl1BMY          = BB(:,25);
    bl1BMZ          = BB(:,27);
    bl1ShearY       = BB(:,29);
    bl1ShearZ       = BB(:,31);
    
    % Blade 2
    bl2Axial        = BB(:,33);
    bl2Tors         = BB(:,34);
    bl2BMY          = BB(:,35);
    bl2BMZ          = BB(:,37);
    bl2ShearY       = BB(:,39);
    bl2ShearZ       = BB(:,41);
    
    
    clear('fid','fname','data','BB','sizeBB','chanNames','chanWave','dt')
%%END READ SIMULATION OUTPUT

%==========================================================================

%% DESCRIPTION OF TIME SERIES available in the workspace
% =========================================================================
% Platform motions and wave elevation:
%   Time variable:             time_SIMO (mx1)  : s
%   Platform positions:        PlatMotions (mx6): m,m,m,deg,deg,deg
%   Wave elevation at origin   wave(mx1)        : m 

% Wind turbine results : 
%   Time variable:             time_RIFLEX (jx1): s
%   Thrust (shaft x):          AeroForceX (jx1) : kN
%   Aero. torque (about shaft):AeroMomX (jx1)   : kNm (rotor inertia NOT INCLUDED) 
%   Wind speed (shaft x):      HubWindX (jx1)   : m/s (at hub pos)
%   Wind speed (shaft y):      HubWindY (jx1)   : m/s (at hub pos)
%   Wind speed (shaft z):      HubWindZ (jx1)   : m/s (at hub pos)
%   Rotor speed:               omega (jx1)      : rad/s
%   Generator power:           genPwr (jx1)     : kW (including efficiency)
%   Generator torque:          genTq (jx1)      : kNm (HSS)
%   Azimuth angle:             azimuth (jx1)    : deg 

% Internal force results at the tower base: 
%   Time variable:              time_RIFLEX (jx1)       : s
%   Axial force at tower base:  TowerBaseAxial (jx1)    : kN  (DOF1)
%   Bending mom. Y at tow base: TowerBaseBMY (jx1)      : kNm (DOF3)
%   Bending mom. Z at tow base: TowerBaseBMZ (jx1)      : kNm (DOF5)
%   Shear force Y at tow base:  TowerBaseShearY (jx1)   : kN  (DOF7)
%   Shear force Z at tow base:  TowerBaseShearZ (jx1)   : kN  (DOF9)
%   Torsional moment tow base:  TowerBaseTors (jx1)     : kNm (DOF2)

% Internal force results at the blade root for blade 1: 
%   Time variable:              time_RIFLEX (jx1)       : s
%   Axial force at tower base:  bl1Axial (jx1)          : kN  (DOF1)
%   Bending mom. Y at tow base: bl1BMY (jx1)            : kNm (DOF3)
%   Bending mom. Z at tow base: bl1BMZ (jx1)            : kNm (DOF5)
%   Shear force Y at tow base:  bl1ShearY (jx1)         : kN  (DOF7)
%   Shear force Z at tow base:  bl1ShearZ (jx1)         : kN  (DOF9)
%   Torsional moment tow base:  bl1Tors (jx1)           : kNm (DOF2)

% Internal force results at the blade root for blade 2: 
%   Time variable:              time_RIFLEX (jx1)       : s
%   Axial force at tower base:  bl2Axial (jx1)          : kN  (DOF1)
%   Bending mom. Y at tow base: bl2BMY (jx1)            : kNm (DOF3)
%   Bending mom. Z at tow base: bl2BMZ (jx1)            : kNm (DOF5)
%   Shear force Y at tow base:  bl2ShearY (jx1)         : kN  (DOF7)
%   Shear force Z at tow base:  bl2ShearZ (jx1)         : kN  (DOF9)
%   Torsional moment tow base:  bl2Tors (jx1)           : kNm (DOF2)

% =========================================================================
%% Post-processing
%  Statistical analysis, fatigue calculation, etc
%  Remember to cut out the first part of the time series
%  Hint: 
%           t_start = 400;
%           indS = sum(time_SIMO<=t_start);
%           mean(PlatMotions(indS:end))



t_start = 400;
indS = sum(time_SIMO<=t_start);
Mean_rotor_speed(1,i)=mean(omega(indS:end,1));
Mean_thrust(1,i)= mean(AeroForceX(indS:end,1));
Mean_torque(1,i)=mean(genTq(indS:end,1));
Mean_power(1,i)=mean(genPwr(indS:end,1));
Mean_blade_pitch(1,i)=(mean(Bl1Pitch(indS:end,1))+ mean(Bl2Pitch(indS:end,1))+ mean(Bl3Pitch(indS:end,1)))/3;
Mean_platform_surge(1,i) = mean(SurgeMotions(indS:end,1));
Mean_platform_pitch(1,i) = mean(PitchMotions(indS:end,1)); 


windspeeds = [4 6 8 10 11.4 12 14 16 18 20 22 24]; 

%Plot time series 
if (windspeeds(i) == 8 || windspeeds(i) == 11.4 || windspeeds(i) == 18)
plot(time_RIFLEX(1:10000), AeroForceX(1:10000));
windspeed = strcat(num2str(windspeeds(1,i)), 'm/s');
title([' Thrust, wind speed:' windspeed ])
xlabel('Time(s)')
ylabel('Mean thrust(kN)')
figure
end


end

%Plot wind turbine parameters vs windspeed
figure;
plot(windspeeds, Mean_rotor_speed,'-o')
title('Mean Rotor Speed, Floating Platform')
xlabel('Wind speed(m/s)')
ylabel('Rotor speed (rad/s)')
figure;
plot(windspeeds, Mean_thrust,'-o')
title('Mean Thrust, Floating Platform')
xlabel('Wind speed(m/s)')
ylabel('Mean thrust (kN)')
figure;
plot(windspeeds, Mean_torque,'-o')
title('Mean Generator Torque, Floating Platform')
xlabel('Wind speed(m/s)')
ylabel('Mean torque on generator (kNm)')
figure;
plot(windspeeds, Mean_power,'-o')
title('Mean Generator Power, Floating Platform')
xlabel('Wind speed(m/s)')
ylabel('Mean generator power (kW)')
ylim([0,6000])
figure;
plot(windspeeds, Mean_blade_pitch,'-o')
title('Mean Blade Pitch, Floating Platform')
xlabel('Wind speed(m/s)')
ylabel('Mean blade pitch (deg)')
figure;
plot(windspeeds, Mean_platform_surge,'-o')
title('Mean Platform Surge, Floating Platform')
xlabel('Wind speed(m/s)')
ylabel('Platform Surge (m)')
figure;
plot(windspeeds, Mean_platform_pitch,'-o')
title('Mean Platform Pitch, Floating Platform')
xlabel('Wind speed(m/s)')
ylabel('Platform Pitch (deg)')



