% readTimeDomainResults  Reads in results from a single simulation 
% 

% close all
% clear all
% clc

%Define number of conditions
n = 15;   

%Preallocate requested means and standard deviations
MaxSurge = zeros(2,n); 
MaxHeave = zeros(2,n);
MaxRoll = zeros(2,n);
MaxPitch = zeros(2,n); 
MaxYaw = zeros(2,n); 
MaxTowerBaseMomentY = zeros(2,n); 
MaxTowerBaseMomentZ = zeros(2,n); 
MaxTowerTopMomentY = zeros(2,n); 
MaxTowerTopMomentZ = zeros(2,n); 
MaxBladeRoot1MomentY = zeros(2,n); 
MaxBladeRoot1MomentZ = zeros(2,n); 
MaxBladeRoot2MomentY = zeros(2,n); 
MaxBladeRoot2MomentZ = zeros(2,n); 

%Preallocate time until stopped turbine 
timeToStop = zeros(1,3);
%Figure numbers
fignum = 1; 
%Cross-section parameters 
D_y = 6.5; 
thk = 0.027; 
D_i = D_y-2*thk; 
A = pi/4*(D_y^2-D_i^2); 
I_y = pi/64*(D_y^4-D_i^4); 
I_z = I_y; 


%% User-defined input
for i = 1:n
condition = num2str(i); 
folder = strcat('C:\Users\dreng\OneDrive\Dokumenter\NTNU\Hst 2018\Integrated dynamic analysis of wind turbines\SIMA\CSC5MW\FaultfreeSimsPhase3\cond1_',condition);
prefix = 'sima';
hullBody = 1; % typically 1 

%% READ SIMULATION OUTPUT
%==========================================================================
%%READ SIMULATION OUTPUT
    % Read the SIMO results text file to get the channel names and number
    % of steps
    [nchan, nts, dt, chanNames] = readSIMO_resultstext([folder '\results.txt']);
    % Read the binary file
    BB = read_simoresults([folder '\results.tda'],nts);
    sizeBB = size(BB);
    if (sizeBB(1)<nts || nts<1); disp('Unable to read SIMO results'); return; end;
    % Determine which channels to read for the platform motions, wave
    % elevation
    [chanMotions, chanWave] = getchannelNumbers(chanNames,hullBody);
    if (chanMotions(1)<1 || chanWave<1); disp('Unable to read SIMO results'); return; end;
    time_SIMO = BB(:,2);
    
    % summarize data in matrix
    PlatMotions = BB(:,chanMotions);
    SurgeMotions = PlatMotions(:,1);
    SwayMotions = PlatMotions(:,2); 
    HeaveMotions = PlatMotions(:,3); 
    RollMotions = PlatMotions(:,4); 
    PitchMotions = PlatMotions(:,5);
    YawMotions = PlatMotions(:,6); 
    wave = BB(:,chanWave);

    % Read the wind turbine results 
    fname = [folder '\' prefix '_witurb.bin'];
    BB = read_rifbin(fname,0,26);
    sizeBB = size(BB);
    Nt = sizeBB(1); % get the number of time steps
    if Nt<2; disp('Unable to read RIFLEX wind turbine results'); return; end; 
    
    time_RIFLEX = BB(:,2);
    omega = BB(:,3)*pi/180; % convert from deg/s to rad/s
    genTq = BB(:,5); 
    genPwr = BB(:,6)*94.4/100; % generator efficiency included
    azimuth = BB(:,7); 
    HubWindX = BB(:,8);
    HubWindY = BB(:,9);
    HubWindZ = BB(:,10);
    AeroForceX = BB(:,11);
    AeroMomX = BB(:,14);
    Bl1Pitch = BB(:,17);
    Bl2Pitch = BB(:,18);
    Bl3Pitch = BB(:,19); 

    % Read the RIFLEX force output file
    fname = [folder '\' prefix '_elmfor.bin'];
    BB = read_rifbin(fname,Nt);
    sizeBB = size(BB);
    if(sizeBB(1)<Nt); disp('Unable to read RIFLEX force results'); return; end;  

    % Tower Base
    TowerBaseAxial  = BB(:,3);
    TowerBaseTors   = BB(:,4);
    TowerBaseBMY    = BB(:,5);
    TowerBaseBMZ    = BB(:,7);
    TowerBaseShearY = BB(:,9);
    TowerBaseShearZ = BB(:,11);

    % Tower Top
    TowerTopAxial  = BB(:,13);
    TowerTopTors   = BB(:,14);
    TowerTopBMY    = BB(:,16); % end 2
    TowerTopBMZ    = BB(:,18);
    TowerTopShearY = BB(:,20);
    TowerTopShearZ = BB(:,22);    
    
    % Blade 1
    bl1Axial        = BB(:,23);
    bl1Tors         = BB(:,24);
    bl1BMY          = BB(:,25);
    bl1BMZ          = BB(:,27);
    bl1ShearY       = BB(:,29);
    bl1ShearZ       = BB(:,31);
    
    % Blade 2
    bl2Axial        = BB(:,33);
    bl2Tors         = BB(:,34);
    bl2BMY          = BB(:,35);
    bl2BMZ          = BB(:,37);
    bl2ShearY       = BB(:,39);
    bl2ShearZ       = BB(:,41);
    
    
    clear('fid','fname','data','BB','sizeBB','chanNames','chanWave','dt')
%%END READ SIMULATION OUTPUT

%==========================================================================

%% DESCRIPTION OF TIME SERIES available in the workspace
% =========================================================================
% Platform motions and wave elevation:
%   Time variable:             time_SIMO (mx1)  : s
%   Platform positions:        PlatMotions (mx6): m,m,m,deg,deg,deg
%   Wave elevation at origin   wave(mx1)        : m 

% Wind turbine results : 
%   Time variable:             time_RIFLEX (jx1): s
%   Thrust (shaft x):          AeroForceX (jx1) : kN
%   Aero. torque (about shaft):AeroMomX (jx1)   : kNm (rotor inertia NOT INCLUDED) 
%   Wind speed (shaft x):      HubWindX (jx1)   : m/s (at hub pos)
%   Wind speed (shaft y):      HubWindY (jx1)   : m/s (at hub pos)
%   Wind speed (shaft z):      HubWindZ (jx1)   : m/s (at hub pos)
%   Rotor speed:               omega (jx1)      : rad/s
%   Generator power:           genPwr (jx1)     : kW (including efficiency)
%   Generator torque:          genTq (jx1)      : kNm (HSS)
%   Azimuth angle:             azimuth (jx1)    : deg 

% Internal force results at the tower base: 
%   Time variable:              time_RIFLEX (jx1)       : s
%   Axial force at tower base:  TowerBaseAxial (jx1)    : kN  (DOF1)
%   Bending mom. Y at tow base: TowerBaseBMY (jx1)      : kNm (DOF3)
%   Bending mom. Z at tow base: TowerBaseBMZ (jx1)      : kNm (DOF5)
%   Shear force Y at tow base:  TowerBaseShearY (jx1)   : kN  (DOF7)
%   Shear force Z at tow base:  TowerBaseShearZ (jx1)   : kN  (DOF9)
%   Torsional moment tow base:  TowerBaseTors (jx1)     : kNm (DOF2)

% Internal force results at the blade root for blade 1: 
%   Time variable:              time_RIFLEX (jx1)       : s
%   Axial force at tower base:  bl1Axial (jx1)          : kN  (DOF1)
%   Bending mom. Y at tow base: bl1BMY (jx1)            : kNm (DOF3)
%   Bending mom. Z at tow base: bl1BMZ (jx1)            : kNm (DOF5)
%   Shear force Y at tow base:  bl1ShearY (jx1)         : kN  (DOF7)
%   Shear force Z at tow base:  bl1ShearZ (jx1)         : kN  (DOF9)
%   Torsional moment tow base:  bl1Tors (jx1)           : kNm (DOF2)

% Internal force results at the blade root for blade 2: 
%   Time variable:              time_RIFLEX (jx1)       : s
%   Axial force at tower base:  bl2Axial (jx1)          : kN  (DOF1)
%   Bending mom. Y at tow base: bl2BMY (jx1)            : kNm (DOF3)
%   Bending mom. Z at tow base: bl2BMZ (jx1)            : kNm (DOF5)
%   Shear force Y at tow base:  bl2ShearY (jx1)         : kN  (DOF7)
%   Shear force Z at tow base:  bl2ShearZ (jx1)         : kN  (DOF9)
%   Torsional moment tow base:  bl2Tors (jx1)           : kNm (DOF2)

% =========================================================================
%% Post-processing
%  Statistical analysis, fatigue calculation, etc
%  Remember to cut out the first part of the time series
%  Hint: 
%           t_start = 400;
%           indS = sum(time_SIMO<=t_start);
%           mean(PlatMotions(indS:end))


%Define where stationary process starts
t_start = 400;
indS = sum(time_SIMO<=t_start);
time = time_RIFLEX(indS:end)-t_start;


%-----------Compute requested max values and time of ocurrence------------
if (i == 8) || (i==14) || (i==15) 
%Motions
[MaxSurge(1,i), maxPosSurge] = max(abs(SurgeMotions(indS:end)));
MaxSurge(2,i) = time(maxPosSurge);
MaxSurge(:,~any(MaxSurge,1))=[];
[MaxHeave(1,i), maxPosHeave] = max(abs(HeaveMotions(indS:end)));
MaxHeave(2,i) = time(maxPosHeave);
MaxHeave(:,~any(MaxHeave,1))=[];
[MaxRoll(1,i), maxPosRoll] = max(abs(RollMotions(indS:end)));
MaxRoll(2,i) = time(maxPosRoll);
MaxRoll(:,~any(MaxRoll,1))=[];
[MaxPitch(1,i), maxPosPitch] = max(abs(PitchMotions(indS:end)));
MaxPitch(2,i) = time(maxPosPitch);
MaxPitch(:,~any(MaxPitch,1))=[];
[MaxYaw(1,i), maxPosYaw] = max(abs(YawMotions(indS:end)));
MaxYaw(2,i) = time(maxPosYaw);
MaxYaw(:,~any(MaxYaw,1))=[];

%Tower Moments
[MaxTowerBaseMomentY(1,i), maxPosBaseY] = max(abs(TowerBaseBMY(indS:end))); %kNm
MaxTowerBaseMomentY(2,i) = time(maxPosBaseY); 
MaxTowerBaseMomentY(:,~any(MaxTowerBaseMomentY,1))=[];
[MaxTowerBaseMomentZ(1,i), maxPosBaseZ] = max(abs(TowerBaseBMZ(indS:end))); %kNm
MaxTowerBaseMomentZ(2,i) = time(maxPosBaseZ); 
MaxTowerBaseMomentZ(:,~any(MaxTowerBaseMomentZ,1))=[];
[MaxTowerTopMomentY(1,i), maxPosTopY] = max(abs(TowerTopBMY(indS:end))); %kNm
MaxTowerTopMomentY(2,i) = time(maxPosTopY); 
MaxTowerTopMomentY(:,~any(MaxTowerTopMomentY,1))=[];
[MaxTowerTopMomentZ(1,i), maxPosTopZ] = max(abs(TowerTopBMZ(indS:end))); %kNm
MaxTowerTopMomentZ(2,i) = time(maxPosTopZ); 
MaxTowerTopMomentZ(:,~any(MaxTowerTopMomentZ,1))=[];

%Blade Moments
[MaxBladeRoot1MomentY(1,i), MaxRoot1Y]= max(abs(bl1BMY(indS:end))); 
MaxBladeRoot1MomentY(2,i) = time(MaxRoot1Y); 
MaxBladeRoot1MomentY(:,~any(MaxBladeRoot1MomentY,1))=[];
[MaxBladeRoot1MomentZ(1,i), MaxRoot1Z]= max(abs(bl1BMZ(indS:end))); 
MaxBladeRoot1MomentZ(2,i) = time(MaxRoot1Z); 
MaxBladeRoot1MomentZ(:,~any(MaxBladeRoot1MomentZ,1))=[];
[MaxBladeRoot2MomentY(1,i), MaxRoot2Y]= max(abs(bl2BMY(indS:end))); 
MaxBladeRoot2MomentY(2,i) = time(MaxRoot2Y);
MaxBladeRoot2MomentY(:,~any(MaxBladeRoot2MomentY,1))=[];
[MaxBladeRoot2MomentZ(1,i), MaxRoot2Z]= max(abs(bl2BMZ(indS:end))); 
MaxBladeRoot2MomentZ(2,i) = time(MaxRoot2Z);
MaxBladeRoot2MomentZ(:,~any(MaxBladeRoot2MomentZ,1))=[];

% %Find time until turbine has stopped
% t_ = 1000;
% actuatorBlockTime = sum(time_SIMO<=t_); 
% ratedSpeed = mean(omega(indS:actuatorBlockTime));
% stoppedSpeed = 0.05*ratedSpeed; 
% rotorSpeed = omega(indS:end); 
% if (i == 4) || (i==5) || (i==6)  
% diff = rotorSpeed-stoppedSpeed;
% for ii = 1:length(diff)
%     if diff(ii:end) <= 0
%        timeToStop(i-3) = time(ii)-(t_-t_start); break 
%     end
% end
% 
% end
end
end

readTimeDomainResults_phase3pitchfault

%-----------Plot maxima -----------
conditions = [8 14 15];
cases = categorical({'F1-F4-8','F2-F5-14','F3-F6-15'}); 


% % Plot maxima in surge
MaxSurgePlot = [MaxFaultSurge(1,1) MaxFaultSurge(1,4) MaxSurge(1,1);...
              MaxFaultSurge(1,2) MaxFaultSurge(1,5) MaxSurge(1,2);...
              MaxFaultSurge(1,3) MaxFaultSurge(1,6) MaxSurge(1,3)];  
 SurgeTimeMax =[round(MaxFaultSurge(2,1)) round(MaxFaultSurge(2,4)) round(MaxSurge(2,1));...
               round(MaxFaultSurge(2,2)) round(MaxFaultSurge(2,5)) round(MaxSurge(2,2));...
               round(MaxFaultSurge(2,3)) round(MaxFaultSurge(2,6)) round(MaxSurge(2,3))];
         
           
figure(fignum);
% plotMax(MaxSurgePlot,addSurgeTimes)
bar(cases,MaxSurgePlot)
%plotMax(MaxSurgePlot, SurgeTimeMax)
xlabel('Fault number and condition'); 
ylabel('Maximum [m]');
title('Surge Maxima'); 
% legend('Fault without shutdown','Fault with shutdown','Fault-free') 


fignum = fignum +1; 

figure(fignum);
% plotMax(MaxSurgePlot,addSurgeTimes)
bar(cases,SurgeTimeMax)
%plotMax(MaxSurgePlot, SurgeTimeMax)
xlabel('Fault number and condition'); 
ylabel('Time [s]');
title('Surge Time Maxima'); 
% legend('Fault without shutdown','Fault with shutdown','Fault-free') 

fignum = fignum +1; 

% % Plot maxima in heave
MaxHeavePlot = [MaxFaultHeave(1,1) MaxFaultHeave(1,4) MaxHeave(1,1);...
              MaxFaultHeave(1,2) MaxFaultHeave(1,5) MaxHeave(1,2);...
              MaxFaultHeave(1,3) MaxFaultHeave(1,6) MaxHeave(1,3)];  
HeaveTimeMax =[round(MaxFaultHeave(2,1)) round(MaxFaultHeave(2,4)) round(MaxHeave(2,1));...
              round(MaxFaultHeave(2,2)) round(MaxFaultHeave(2,5)) round(MaxHeave(2,2));...
              round(MaxFaultHeave(2,3)) round(MaxFaultHeave(2,6)) round(MaxHeave(2,3))];

figure(fignum);
% plotMax(MaxHeavePlot,addHeaveTimes)
bar(cases,MaxHeavePlot)
xlabel('Fault number and condition'); 
ylabel('Maximum [m]');
title('Heave Maxima'); 


fignum = fignum +1; 

figure(fignum);
bar(cases,HeaveTimeMax)
xlabel('Fault number and condition'); 
ylabel('Time [s]');
title('Heave Time Maxima'); 

fignum = fignum +1;

% % Plot maxima in Roll
MaxRollPlot = [MaxFaultRoll(1,1) MaxFaultRoll(1,4) MaxRoll(1,1);...
              MaxFaultRoll(1,2) MaxFaultRoll(1,5) MaxRoll(1,2);...
              MaxFaultRoll(1,3) MaxFaultRoll(1,6) MaxRoll(1,3)];  
RollTimeMax =[round(MaxFaultRoll(2,1)) round(MaxFaultRoll(2,4)) round(MaxRoll(2,1));...
              round(MaxFaultRoll(2,2)) round(MaxFaultRoll(2,5)) round(MaxRoll(2,2));...
              round(MaxFaultRoll(2,3)) round(MaxFaultRoll(2,6)) round(MaxRoll(2,3))];

figure(fignum);
% plotMax(MaxRollPlot,addRollTimes)
bar(cases,MaxRollPlot)
xlabel('Fault number and condition'); 
ylabel('Maximum [deg]');
title('Roll Maxima'); 


fignum = fignum +1; 

figure(fignum);
bar(cases,RollTimeMax)
xlabel('Fault number and condition'); 
ylabel('Time [s]');
title('Roll Time Maxima'); 

fignum = fignum +1;

% % Plot maxima in pitch
MaxPitchPlot = [MaxFaultPitch(1,1) MaxFaultPitch(1,4) MaxPitch(1,1);...
              MaxFaultPitch(1,2) MaxFaultPitch(1,5) MaxPitch(1,2);...
              MaxFaultPitch(1,3) MaxFaultPitch(1,6) MaxPitch(1,3)];  
PitchTimeMax =[round(MaxFaultPitch(2,1)) round(MaxFaultPitch(2,4)) round(MaxPitch(2,1));...
              round(MaxFaultPitch(2,2)) round(MaxFaultPitch(2,5)) round(MaxPitch(2,2));...
              round(MaxFaultPitch(2,3)) round(MaxFaultPitch(2,6)) round(MaxPitch(2,3))];

figure(fignum);
% plotMax(MaxPitchPlot,addPitchTimes)
bar(cases,MaxPitchPlot)
xlabel('Fault number and condition'); 
ylabel('Maximum [deg]');
title('Pitch Maxima'); 


fignum = fignum +1; 

figure(fignum);
bar(cases,PitchTimeMax)
xlabel('Fault number and condition'); 
ylabel('Time [s]');
title('Pitch Time Maxima'); 
 

fignum = fignum +1;


% % Plot maxima in yaw
MaxYawPlot = [MaxFaultYaw(1,1) MaxFaultYaw(1,4) MaxYaw(1,1);...
              MaxFaultYaw(1,2) MaxFaultYaw(1,5) MaxYaw(1,2);...
              MaxFaultYaw(1,3) MaxFaultYaw(1,6) MaxYaw(1,3)];  
YawTimeMax =[round(MaxFaultYaw(2,1)) round(MaxFaultYaw(2,4)) round(MaxYaw(2,1));...
              round(MaxFaultYaw(2,2)) round(MaxFaultYaw(2,5)) round(MaxYaw(2,2));...
              round(MaxFaultYaw(2,3)) round(MaxFaultYaw(2,6)) round(MaxYaw(2,3))];

figure(fignum);
% plotMax(MaxYawPlot,addYawTimes)
bar(cases,MaxYawPlot)
xlabel('Fault number and condition'); 
ylabel('Maximum [deg]');
title('Yaw Maxima'); 


fignum = fignum +1; 

figure(fignum);
bar(cases,YawTimeMax)
xlabel('Fault number and condition'); 
ylabel('Time [s]');
title('Yaw Time Maxima'); 
% legend('Fault without shutdown','Fault with shutdown','Fault-free') 

fignum = fignum +1;

% % Plot maxima of bending moment Y at tower base
MaxTowerBaseMomentYPlot = [MaxFaultTowerBaseMomentY(1,1) MaxFaultTowerBaseMomentY(1,4) MaxTowerBaseMomentY(1,1);...
              MaxFaultTowerBaseMomentY(1,2) MaxFaultTowerBaseMomentY(1,5) MaxTowerBaseMomentY(1,2);...
              MaxFaultTowerBaseMomentY(1,3) MaxFaultTowerBaseMomentY(1,6) MaxTowerBaseMomentY(1,3)];  
TowerBaseMomentYTimeMax =[round(MaxFaultTowerBaseMomentY(2,1)) round(MaxFaultTowerBaseMomentY(2,4)) round(MaxTowerBaseMomentY(2,1));...
              round(MaxFaultTowerBaseMomentY(2,2)) round(MaxFaultTowerBaseMomentY(2,5)) round(MaxTowerBaseMomentY(2,2));...
              round(MaxFaultTowerBaseMomentY(2,3)) round(MaxFaultTowerBaseMomentY(2,6)) round(MaxTowerBaseMomentY(2,3))];

figure(fignum);
% plotMax(MaxTowerBaseMomentYPlot,addTowerBaseMomentYTimes)
bar(cases,MaxTowerBaseMomentYPlot)
xlabel('Fault number and condition'); 
ylabel('Maximum [kNm]');
title('TowerBaseMomentY Maxima'); 


fignum = fignum +1; 

figure(fignum);
bar(cases,TowerBaseMomentYTimeMax)
xlabel('Fault number and condition'); 
ylabel('Time [s]');
title('TowerBaseMomentY Time Maxima'); 

fignum = fignum +1;


% % Plot maxima of bending moment Z at tower base
MaxTowerBaseMomentZPlot = [MaxFaultTowerBaseMomentZ(1,1) MaxFaultTowerBaseMomentZ(1,4) MaxTowerBaseMomentZ(1,1);...
              MaxFaultTowerBaseMomentZ(1,2) MaxFaultTowerBaseMomentZ(1,5) MaxTowerBaseMomentZ(1,2);...
              MaxFaultTowerBaseMomentZ(1,3) MaxFaultTowerBaseMomentZ(1,6) MaxTowerBaseMomentZ(1,3)];  
TowerBaseMomentZTimeMax =[round(MaxFaultTowerBaseMomentZ(2,1)) round(MaxFaultTowerBaseMomentZ(2,4)) round(MaxTowerBaseMomentZ(2,1));...
              round(MaxFaultTowerBaseMomentZ(2,2)) round(MaxFaultTowerBaseMomentZ(2,5)) round(MaxTowerBaseMomentZ(2,2));...
              round(MaxFaultTowerBaseMomentZ(2,3)) round(MaxFaultTowerBaseMomentZ(2,6)) round(MaxTowerBaseMomentZ(2,3))];

figure(fignum);
% plotMax(MaxTowerBaseMomentZPlot,addTowerBaseMomentZTimes)
bar(cases,MaxTowerBaseMomentZPlot)
xlabel('Fault number and condition'); 
ylabel('Maximum [kNm]');
title('TowerBaseMomentZ Maxima'); 


fignum = fignum +1; 

figure(fignum);
bar(cases,TowerBaseMomentZTimeMax)
xlabel('Fault number and condition'); 
ylabel('Time [s]');
title('TowerBaseMomentZ Time Maxima'); 

fignum = fignum +1;

% % Plot maxima of bending moment Y at tower top
MaxTowerTopMomentYPlot = [MaxFaultTowerTopMomentY(1,1) MaxFaultTowerTopMomentY(1,4) MaxTowerTopMomentY(1,1);...
              MaxFaultTowerTopMomentY(1,2) MaxFaultTowerTopMomentY(1,5) MaxTowerTopMomentY(1,2);...
              MaxFaultTowerTopMomentY(1,3) MaxFaultTowerTopMomentY(1,6) MaxTowerTopMomentY(1,3)];  
TowerTopMomentYTimeMax =[round(MaxFaultTowerTopMomentY(2,1)) round(MaxFaultTowerTopMomentY(2,4)) round(MaxTowerTopMomentY(2,1));...
              round(MaxFaultTowerTopMomentY(2,2)) round(MaxFaultTowerTopMomentY(2,5)) round(MaxTowerTopMomentY(2,2));...
              round(MaxFaultTowerTopMomentY(2,3)) round(MaxFaultTowerTopMomentY(2,6)) round(MaxTowerTopMomentY(2,3))];

figure(fignum);
% plotMax(MaxTowerTopMomentYPlot,addTowerTopMomentYTimes)
bar(cases,MaxTowerTopMomentYPlot)
xlabel('Fault number and condition'); 
ylabel('Maximum [kNm]');
title('TowerTopMomentY Maxima'); 

fignum = fignum +1; 

figure(fignum);
bar(cases,TowerTopMomentYTimeMax)
xlabel('Fault number and condition'); 
ylabel('Time [s]');
title('TowerTopMomentY Time Maxima'); 

fignum = fignum +1;

% % Plot maxima of bending moment Z at tower top
MaxTowerTopMomentZPlot = [MaxFaultTowerTopMomentZ(1,1) MaxFaultTowerTopMomentZ(1,4) MaxTowerTopMomentZ(1,1);...
              MaxFaultTowerTopMomentZ(1,2) MaxFaultTowerTopMomentZ(1,5) MaxTowerTopMomentZ(1,2);...
              MaxFaultTowerTopMomentZ(1,3) MaxFaultTowerTopMomentZ(1,6) MaxTowerTopMomentZ(1,3)];  
TowerTopMomentZTimeMax =[round(MaxFaultTowerTopMomentZ(2,1)) round(MaxFaultTowerTopMomentZ(2,4)) round(MaxTowerTopMomentZ(2,1));...
              round(MaxFaultTowerTopMomentZ(2,2)) round(MaxFaultTowerTopMomentZ(2,5)) round(MaxTowerTopMomentZ(2,2));...
              round(MaxFaultTowerTopMomentZ(2,3)) round(MaxFaultTowerTopMomentZ(2,6)) round(MaxTowerTopMomentZ(2,3))];

figure(fignum);
% plotMax(MaxTowerTopMomentZPlot,addTowerTopMomentZTimes)
bar(cases,MaxTowerTopMomentZPlot)
xlabel('Fault number and condition'); 
ylabel('Maximum [kNm]');
title('TowerTopMomentZ Maxima'); 


fignum = fignum +1; 

figure(fignum);
bar(cases,TowerTopMomentZTimeMax)
xlabel('Fault number and condition'); 
ylabel('Time [s]');
title('TowerTopMomentZ Time Maxima'); 

fignum = fignum +1;

% % Plot maxima of bending moment Y at bladeroot 1
MaxBladeRoot1MomentYPlot = [MaxFaultBladeRoot1MomentY(1,1) MaxFaultBladeRoot1MomentY(1,4) MaxBladeRoot1MomentY(1,1);...
              MaxFaultBladeRoot1MomentY(1,2) MaxFaultBladeRoot1MomentY(1,5) MaxBladeRoot1MomentY(1,2);...
              MaxFaultBladeRoot1MomentY(1,3) MaxFaultBladeRoot1MomentY(1,6) MaxBladeRoot1MomentY(1,3)];  
BladeRoot1MomentYTimeMax =[round(MaxFaultBladeRoot1MomentY(2,1)) round(MaxFaultBladeRoot1MomentY(2,4)) round(MaxBladeRoot1MomentY(2,1));...
              round(MaxFaultBladeRoot1MomentY(2,2)) round(MaxFaultBladeRoot1MomentY(2,5)) round(MaxBladeRoot1MomentY(2,2));...
              round(MaxFaultBladeRoot1MomentY(2,3)) round(MaxFaultBladeRoot1MomentY(2,6)) round(MaxBladeRoot1MomentY(2,3))];

figure(fignum);
% plotMax(MaxBladeRoot1MomentYPlot,addBladeRoot1MomentYTimes)
bar(cases,MaxBladeRoot1MomentYPlot)
xlabel('Fault number and condition'); 
ylabel('Maximum [kNm]');
title('BladeRoot1MomentY Maxima'); 


fignum = fignum +1; 

figure(fignum);
bar(cases,BladeRoot1MomentYTimeMax)
xlabel('Fault number and condition'); 
ylabel('Time [s]');
title('BladeRoot1MomentY Time Maxima'); 

fignum = fignum +1;

% % Plot maxima of bending moment Z at bladeroot 1
MaxBladeRoot1MomentZPlot = [MaxFaultBladeRoot1MomentZ(1,1) MaxFaultBladeRoot1MomentZ(1,4) MaxBladeRoot1MomentZ(1,1);...
              MaxFaultBladeRoot1MomentZ(1,2) MaxFaultBladeRoot1MomentZ(1,5) MaxBladeRoot1MomentZ(1,2);...
              MaxFaultBladeRoot1MomentZ(1,3) MaxFaultBladeRoot1MomentZ(1,6) MaxBladeRoot1MomentZ(1,3)];  
BladeRoot1MomentZTimeMax =[round(MaxFaultBladeRoot1MomentZ(2,1)) round(MaxFaultBladeRoot1MomentZ(2,4)) round(MaxBladeRoot1MomentZ(2,1));...
              round(MaxFaultBladeRoot1MomentZ(2,2)) round(MaxFaultBladeRoot1MomentZ(2,5)) round(MaxBladeRoot1MomentZ(2,2));...
              round(MaxFaultBladeRoot1MomentZ(2,3)) round(MaxFaultBladeRoot1MomentZ(2,6)) round(MaxBladeRoot1MomentZ(2,3))];

figure(fignum);
% plotMax(MaxBladeRoot1MomentZPlot,addBladeRoot1MomentZTimes)
bar(cases,MaxBladeRoot1MomentZPlot)
xlabel('Fault number and condition'); 
ylabel('Maximum [kNm]');
title('BladeRoot1MomentZ Maxima'); 


fignum = fignum +1; 

figure(fignum);
bar(cases,BladeRoot1MomentZTimeMax)
xlabel('Fault number and condition'); 
ylabel('Time [s]');
title('BladeRoot1MomentZ Time Maxima'); 

fignum = fignum +1;

% % Plot maxima of bending moment Y at bladeroot 2
MaxBladeRoot2MomentYPlot = [MaxFaultBladeRoot2MomentY(1,1) MaxFaultBladeRoot2MomentY(1,4) MaxBladeRoot2MomentY(1,1);...
              MaxFaultBladeRoot2MomentY(1,2) MaxFaultBladeRoot2MomentY(1,5) MaxBladeRoot2MomentY(1,2);...
              MaxFaultBladeRoot2MomentY(1,3) MaxFaultBladeRoot2MomentY(1,6) MaxBladeRoot2MomentY(1,3)];  
BladeRoot2MomentYTimeMax =[round(MaxFaultBladeRoot2MomentY(2,1)) round(MaxFaultBladeRoot2MomentY(2,4)) round(MaxBladeRoot2MomentY(2,1));...
              round(MaxFaultBladeRoot2MomentY(2,2)) round(MaxFaultBladeRoot2MomentY(2,5)) round(MaxBladeRoot2MomentY(2,2));...
              round(MaxFaultBladeRoot2MomentY(2,3)) round(MaxFaultBladeRoot2MomentY(2,6)) round(MaxBladeRoot2MomentY(2,3))];

figure(fignum);
% plotMax(MaxBladeRoot2MomentYPlot,addBladeRoot2MomentYTimes)
bar(cases,MaxBladeRoot2MomentYPlot)
xlabel('Fault number and condition'); 
ylabel('Maximum [kNm]');
title('BladeRoot2MomentY Maxima'); 


fignum = fignum +1; 

figure(fignum);
bar(cases,BladeRoot2MomentYTimeMax)
xlabel('Fault number and condition'); 
ylabel('Time [s]');
title('BladeRoot2MomentY Time Maxima'); 

fignum = fignum +1;

% % Plot maxima of bending moment Z at bladeroot 2
MaxBladeRoot2MomentZPlot = [MaxFaultBladeRoot2MomentZ(1,1) MaxFaultBladeRoot2MomentZ(1,4) MaxBladeRoot2MomentZ(1,1);...
              MaxFaultBladeRoot2MomentZ(1,2) MaxFaultBladeRoot2MomentZ(1,5) MaxBladeRoot2MomentZ(1,2);...
              MaxFaultBladeRoot2MomentZ(1,3) MaxFaultBladeRoot2MomentZ(1,6) MaxBladeRoot2MomentZ(1,3)];  
BladeRoot2MomentZTimeMax =[round(MaxFaultBladeRoot2MomentZ(2,1)) round(MaxFaultBladeRoot2MomentZ(2,4)) round(MaxBladeRoot2MomentZ(2,1));...
              round(MaxFaultBladeRoot2MomentZ(2,2)) round(MaxFaultBladeRoot2MomentZ(2,5)) round(MaxBladeRoot2MomentZ(2,2));...
              round(MaxFaultBladeRoot2MomentZ(2,3)) round(MaxFaultBladeRoot2MomentZ(2,6)) round(MaxBladeRoot2MomentZ(2,3))];

figure(fignum);
% plotMax(MaxBladeRoot2MomentZPlot,addBladeRoot2MomentZTimes)
bar(cases,MaxBladeRoot2MomentZPlot)
xlabel('Fault number and condition'); 
ylabel('Maximum [kNm]');
title('BladeRoot2MomentZ Maxima'); 

fignum = fignum +1;

figure(fignum);
bar(cases,BladeRoot2MomentZTimeMax)
xlabel('Fault number and condition'); 
ylabel('Time [s]');
title('BladeRoot2MomentZ Time Maxima'); 
