% readTimeDomainResults  Reads in results from a single simulation 
% 

% close all
% clear all
% clc

%Define number of conditions and seeds for each condition
n = 6;   

%Preallocate requested means and standard deviations
MaxFaultSurge = zeros(2,n); 
MaxFaultHeave = zeros(2,n); 
MaxFaultRoll = zeros(2,n);
MaxFaultPitch = zeros(2,n); 
MaxFaultYaw = zeros(2,n); 
MaxFaultTowerBaseMomentY = zeros(2,n); 
MaxFaultTowerBaseMomentZ = zeros(2,n); 
MaxFaultTowerTopMomentY = zeros(2,n); 
MaxFaultTowerTopMomentZ = zeros(2,n); 
MaxFaultBladeRoot1MomentY = zeros(2,n); 
MaxFaultBladeRoot1MomentZ = zeros(2,n); 
MaxFaultBladeRoot2MomentY = zeros(2,n); 
MaxFaultBladeRoot2MomentZ = zeros(2,n); 

%Preallocate time until stopped turbine 
timeToStop = zeros(1,3);
%Figure numbers
fignum = 1; 
%Cross-section parameters 
D_y = 6.5; 
thk = 0.027; 
D_i = D_y-2*thk; 
A = pi/4*(D_y^2-D_i^2); 
I_y = pi/64*(D_y^4-D_i^4); 
I_z = I_y; 


%% User-defined input
for i = 1:n
condition = num2str(i); 
folder = strcat('C:\Users\dreng\OneDrive\Dokumenter\NTNU\Hst 2018\Integrated dynamic analysis of wind turbines\SIMA\CSC5MW\controller_fault\controller_fault_',condition);
prefix = 'sima';
hullBody = 1; % typically 1 

%% READ SIMULATION OUTPUT
%==========================================================================
%%READ SIMULATION OUTPUT
    % Read the SIMO results text file to get the channel names and number
    % of steps
    [nchan, nts, dt, chanNames] = readSIMO_resultstext([folder '\results.txt']);
    % Read the binary file
    BB = read_simoresults([folder '\results.tda'],nts);
    sizeBB = size(BB);
    if (sizeBB(1)<nts || nts<1); disp('Unable to read SIMO results'); return; end;
    % Determine which channels to read for the platform motions, wave
    % elevation
    [chanMotions, chanWave] = getchannelNumbers(chanNames,hullBody);
    if (chanMotions(1)<1 || chanWave<1); disp('Unable to read SIMO results'); return; end;
    time_SIMO = BB(:,2);
    
    % summarize data in matrix
    PlatMotions = BB(:,chanMotions);
    SurgeMotionsFault = PlatMotions(:,1);
    SwayMotionsFault = PlatMotions(:,2); 
    HeaveMotionsFault = PlatMotions(:,3); 
    RollMotionsFault = PlatMotions(:,4); 
    PitchMotionsFault = PlatMotions(:,5);
    YawMotionsFault = PlatMotions(:,6); 
    wave = BB(:,chanWave);

    % Read the wind turbine results 
    fname = [folder '\' prefix '_witurb.bin'];
    BB = read_rifbin(fname,0,26);
    sizeBB = size(BB);
    Nt = sizeBB(1); % get the number of time steps
    if Nt<2; disp('Unable to read RIFLEX wind turbine results'); return; end; 
    
    time_RIFLEX = BB(:,2);
    omega = BB(:,3)*pi/180; % convert from deg/s to rad/s
    genTq = BB(:,5); 
    genPwr = BB(:,6)*94.4/100; % generator efficiency included
    azimuth = BB(:,7); 
    HubWindX = BB(:,8);
    HubWindY = BB(:,9);
    HubWindZ = BB(:,10);
    AeroForceX = BB(:,11);
    AeroForceY = BB(:,12);
    AeroForceZ = BB(:,13);
    AeroMomX = BB(:,14);
    AeroMomY = BB(:,15); 
    AeroMomZ = BB(:,16);
    Bl1Pitch = BB(:,17);
    Bl2Pitch = BB(:,18);
    Bl3Pitch = BB(:,19); 

    % Read the RIFLEX force output file
    fname = [folder '\' prefix '_elmfor.bin'];
    BB = read_rifbin(fname,Nt);
    sizeBB = size(BB);
    if(sizeBB(1)<Nt); disp('Unable to read RIFLEX force results'); return; end;  

    % Tower Base
    TowerBaseAxial  = BB(:,3);
    TowerBaseTors   = BB(:,4);
    TowerBaseBMY    = BB(:,5);
    TowerBaseBMZ    = BB(:,7);
    TowerBaseShearY = BB(:,9);
    TowerBaseShearZ = BB(:,11);

    % Tower Top
    TowerTopAxial  = BB(:,13);
    TowerTopTors   = BB(:,14);
    TowerTopBMY    = BB(:,16); % end 2
    TowerTopBMZ    = BB(:,18);
    TowerTopShearY = BB(:,20);
    TowerTopShearZ = BB(:,22);    
    
    % Blade 1
    bl1Axial        = BB(:,23);
    bl1Tors         = BB(:,24);
    bl1BMY          = BB(:,25);
    bl1BMZ          = BB(:,27);
    bl1ShearY       = BB(:,29);
    bl1ShearZ       = BB(:,31);
    
    % Blade 2
    bl2Axial        = BB(:,33);
    bl2Tors         = BB(:,34);
    bl2BMY          = BB(:,35);
    bl2BMZ          = BB(:,37);
    bl2ShearY       = BB(:,39);
    bl2ShearZ       = BB(:,41);
    
    
    clear('fid','fname','data','BB','sizeBB','chanNames','chanWave','dt')
%%END READ SIMULATION OUTPUT

%==========================================================================

%% DESCRIPTION OF TIME SERIES available in the workspace
% =========================================================================
% Platform motions and wave elevation:
%   Time variable:             time_SIMO (mx1)  : s
%   Platform positions:        PlatMotions (mx6): m,m,m,deg,deg,deg
%   Wave elevation at origin   wave(mx1)        : m 

% Wind turbine results : 
%   Time variable:             time_RIFLEX (jx1): s
%   Thrust (shaft x):          AeroForceX (jx1) : kN
%   Aero. torque (about shaft):AeroMomX (jx1)   : kNm (rotor inertia NOT INCLUDED) 
%   Wind speed (shaft x):      HubWindX (jx1)   : m/s (at hub pos)
%   Wind speed (shaft y):      HubWindY (jx1)   : m/s (at hub pos)
%   Wind speed (shaft z):      HubWindZ (jx1)   : m/s (at hub pos)
%   Rotor speed:               omega (jx1)      : rad/s
%   Generator power:           genPwr (jx1)     : kW (including efficiency)
%   Generator torque:          genTq (jx1)      : kNm (HSS)
%   Azimuth angle:             azimuth (jx1)    : deg 

% Internal force results at the tower base: 
%   Time variable:              time_RIFLEX (jx1)       : s
%   Axial force at tower base:  TowerBaseAxial (jx1)    : kN  (DOF1)
%   Bending mom. Y at tow base: TowerBaseBMY (jx1)      : kNm (DOF3)
%   Bending mom. Z at tow base: TowerBaseBMZ (jx1)      : kNm (DOF5)
%   Shear force Y at tow base:  TowerBaseShearY (jx1)   : kN  (DOF7)
%   Shear force Z at tow base:  TowerBaseShearZ (jx1)   : kN  (DOF9)
%   Torsional moment tow base:  TowerBaseTors (jx1)     : kNm (DOF2)

% Internal force results at the blade root for blade 1: 
%   Time variable:              time_RIFLEX (jx1)       : s
%   Axial force at tower base:  bl1Axial (jx1)          : kN  (DOF1)
%   Bending mom. Y at tow base: bl1BMY (jx1)            : kNm (DOF3)
%   Bending mom. Z at tow base: bl1BMZ (jx1)            : kNm (DOF5)
%   Shear force Y at tow base:  bl1ShearY (jx1)         : kN  (DOF7)
%   Shear force Z at tow base:  bl1ShearZ (jx1)         : kN  (DOF9)
%   Torsional moment tow base:  bl1Tors (jx1)           : kNm (DOF2)

% Internal force results at the blade root for blade 2: 
%   Time variable:              time_RIFLEX (jx1)       : s
%   Axial force at tower base:  bl2Axial (jx1)          : kN  (DOF1)
%   Bending mom. Y at tow base: bl2BMY (jx1)            : kNm (DOF3)
%   Bending mom. Z at tow base: bl2BMZ (jx1)            : kNm (DOF5)
%   Shear force Y at tow base:  bl2ShearY (jx1)         : kN  (DOF7)
%   Shear force Z at tow base:  bl2ShearZ (jx1)         : kN  (DOF9)
%   Torsional moment tow base:  bl2Tors (jx1)           : kNm (DOF2)

% =========================================================================
%% Post-processing
%  Statistical analysis, fatigue calculation, etc
%  Remember to cut out the first part of the time series
%  Hint: 
%           t_start = 400;
%           indS = sum(time_SIMO<=t_start);
%           mean(PlatMotions(indS:end))


%Define where stationary process starts
t_start = 400;
indS = sum(time_SIMO<=t_start);
time = time_RIFLEX(indS:end)-t_start;


%-----------Compute requested max values and time of ocurrence------------
%Motions
[MaxFaultSurge(1,i), maxPosSurge] = max(abs(SurgeMotionsFault(indS:end)));
MaxFaultSurge(2,i) = time(maxPosSurge);
[MaxFaultHeave(1,i), maxPosHeave] = max(abs(HeaveMotionsFault(indS:end)));
MaxFaultHeave(2,i) = time(maxPosHeave);
[MaxFaultRoll(1,i), maxPosRoll] = max(abs(RollMotionsFault(indS:end)));
MaxFaultRoll(2,i) = time(maxPosRoll);
[MaxFaultPitch(1,i), maxPosPitch] = max(abs(PitchMotionsFault(indS:end)));
MaxFaultPitch(2,i) = time(maxPosPitch);
[MaxFaultYaw(1,i), maxPosYaw] = max(abs(YawMotionsFault(indS:end)));
MaxFaultYaw(2,i) = time(maxPosYaw); 

%Tower Moments
[MaxFaultTowerBaseMomentY(1,i), maxPosBaseY] = max(abs(TowerBaseBMY(indS:end))); %kNm
MaxFaultTowerBaseMomentY(2,i) = time(maxPosBaseY); 
[MaxFaultTowerBaseMomentZ(1,i), maxPosBaseZ] = max(abs(TowerBaseBMZ(indS:end))); %kNm
MaxFaultTowerBaseMomentZ(2,i) = time(maxPosBaseZ); 
[MaxFaultTowerTopMomentY(1,i), maxPosTopY] = max(abs(TowerTopBMY(indS:end))); %kNm
MaxFaultTowerTopMomentY(2,i) = time(maxPosTopY); 
[MaxFaultTowerTopMomentZ(1,i), maxPosTopZ] = max(abs(TowerTopBMZ(indS:end))); %kNm
MaxFaultTowerTopMomentZ(2,i) = time(maxPosTopZ); 

%Blade Moments
[MaxFaultBladeRoot1MomentY(1,i), MaxRoot1Y]= max(abs(bl1BMY(indS:end))); 
MaxFaultBladeRoot1MomentY(2,i) = time(MaxRoot1Y); 
[MaxFaultBladeRoot1MomentZ(1,i), MaxRoot1Z]= max(abs(bl1BMZ(indS:end))); 
MaxFaultBladeRoot1MomentZ(2,i) = time(MaxRoot1Z); 
[MaxFaultBladeRoot2MomentY(1,i), MaxRoot2Y]= max(abs(bl2BMY(indS:end))); 
MaxFaultBladeRoot2MomentY(2,i) = time(MaxRoot2Y);
[MaxFaultBladeRoot2MomentZ(1,i), MaxRoot2Z]= max(abs(bl2BMZ(indS:end))); 
MaxFaultBladeRoot2MomentZ(2,i) = time(MaxRoot2Z); 

%Blade pitch 
BladeSeries1 = Bl1Pitch(indS:end); 
BladeSeries2 = Bl2Pitch(indS:end); 

%AeroMomentX
Heave = HeaveMotionsFault (indS:end); 
figure(1)
plot(time, Heave)
hold on
xlabel('Time (s)')
ylabel('Heave, (m)')
title('Heave motion of the platform ') 
legend('F1', 'F2', 'F3', 'F4', 'F5', 'F6')


% %Plot the time series of the blade pitch
% figure(1)
% plot(time,BladeSeries1)
% hold on
% xlabel('Time (s)')
% ylabel('Pitch (deg)')
% title('Pitch of blade 1 without fault') 
% legend('F1', 'F2', 'F3', 'F4', 'F5', 'F6')
% ylim([-5, 100])
% figure(2) 
% plot(time,BladeSeries2)
% hold on
% xlabel('Time (s)')
% ylabel('Pitch (deg)') 
% title('Pitch of blade 2 with fault') 
% legend('F1', 'F2', 'F3', 'F4', 'F5', 'F6')

%Find time until turbine has stopped
t_fault = 1000;
actuatorBlockTime = sum(time_SIMO<=t_fault); 
ratedSpeed = mean(omega(indS:actuatorBlockTime));
stoppedSpeed = 0.05*ratedSpeed; 
rotorSpeed = omega(indS:end); 
if (i == 4) || (i==5) || (i==6)  
diff = rotorSpeed-stoppedSpeed;
% figure(25)
% plot(time,diff)
% xlabel('Time (s)')
% ylabel('Criterion speed - Actual speed (rad/s)')
% title('Rotational speed of fault conditions')
% hold on
% legend('F4', 'F5', 'F6')

for ii = 1:length(diff)
    if diff(ii:end) <= 0
       timeToStop(i-3) = time(ii)-(t_fault-t_start); break 
    end
end

end
end
%-----------Plot mean offsets, standard deviation etc-----------
%condition_vector = 1:n; 



% % Plot mean offset in surge
% figure(fignum);
% bar(condition_vector, meanoffset_surge); 
% xlabel('Condition'); 
% ylabel('Mean offset [m]');
% title('Surge mean offset'); 
% 
% fignum = fignum +1; 
% 
% % Plot mean offset in pitch
% figure(fignum);
% bar(condition_vector, meanoffset_pitch); 
% xlabel('Condition'); 
% ylabel('Mean offset [deg]');
% title('Pitch mean offset'); 
% 
% fignum = fignum +1; 
% 
% % Plot std in surge
% figure(fignum);
% bar(condition_vector, std_surge); 
% xlabel('Condition'); 
% ylabel('Std [m]');
% title('Surge standard deviation'); 
% 
% fignum = fignum +1; 
% 
% % Plot std in heave
% figure(fignum);
% bar(condition_vector, std_heave); 
% xlabel('Condition'); 
% ylabel('Std [m]');
% title('Heave standard deviation'); 
% 
% fignum = fignum +1; 
% 
% % Plot std in pitch
% figure(fignum);
% bar(condition_vector, std_pitch); 
% xlabel('Condition'); 
% ylabel('Std [deg]');
% title('Pitch standard deviation'); 
% 
% fignum = fignum +1; 
% 
% % Plot std in yaw
% figure(fignum);
% bar(condition_vector, std_yaw); 
% xlabel('Condition'); 
% ylabel('Std [deg]');
% title('Yaw standard deviation'); 
% 
% fignum = fignum +1; 
% 
% 
% % Mean tower bending moment Y
% figure(fignum);
% bar(condition_vector, abs(mean_towerbendY)); 
% xlabel('Condition'); 
% ylabel('Mean bending moment [kNm]');
% title('Mean tower bending moment, Y'); 
% 
% fignum = fignum +1; 
% 
% 
% % Mean tower bending moment Z
% figure(fignum);
% bar(condition_vector, mean_towerbendZ); 
% xlabel('Condition'); 
% ylabel('Mean bending moment');
% title('Mean tower bending moment, Z'); 
% 
% fignum = fignum +1; 
% 
% %Plot std for tower bending moment Y
% figure(fignum);
% bar(condition_vector, std_towerbendY); 
% xlabel('Condition'); 
% ylabel('Std [kNm]');
% title('Standard deviation, Y-bending moment'); 
% 
% fignum = fignum +1;
% 
% %Plot std for tower bending moment Z
% figure(fignum);
% bar(condition_vector, std_towerbendZ); 
% xlabel('Condition'); 
% ylabel('Std [kNm]');
% title('Standard deviation, Z-bending moment'); 
% 
% fignum = fignum +1;
% 
% %Plot mean rotor speed
% figure(fignum);
% bar(condition_vector, mean_rotorspeed); 
% xlabel('Condition'); 
% ylabel('Mean rotor speed [rad/s]');
% title('Mean rotor speed'); 
% 
% fignum = fignum +1;
% 
% %Plot std rotor speed
% figure(fignum);
% bar(condition_vector, std_rotorspeed); 
% xlabel('Condition'); 
% ylabel('Std [rad/s]');
% title('Standard deviation rotor speed'); 
% 
% fignum = fignum +1;



