%%This script is used for postprocessing of the simulation data and creates
%%plots for comparing with the NDP experimental data for 50% straked risers

close all 
clear all
%Run Strakes50Simulations.m down to "save([MeasPath
%'strakedmeasdata.mat'])" to generate strakedmeasdata.mat
MeasPath='C:\Users\dreng\OneDrive\Dokumenter\NTNU\Riflex_run\Meas\'; 
load([MeasPath 'strakedmeasdata.mat']);

simcases = 23:1:44; %Cases selected for simulation
allcases = 23:1:44; %Vector including all uniform or shear flow cases, different than simcases if a limited number of cases are simulated
                    %Uniform flow cases: 23:1:44;
                    %Shear flow cases: 1:1:22;
Cv=0.85; 
Cvs=num2str(Cv); 

%Establish curr, used to separate uniform and shear when plotting 
if max(simcases)>22
    curr='Uniform'; 
else
    curr='Shear';
end

for ic=simcases

 inpFileName=['ndp38m' num2str(CaseID(ic))]; 
 
%Set directory for stored displacement and curvature data and load the data
cd(['C:\Users\dreng\OneDrive\Dokumenter\NTNU\Riflex_run\Inputfile\STRAKES\NewCDsims\OnlyQuadDamp\Strakespresenceaccounted(H)'])
    load([inpFileName 'dispdata.mat']);
    load([inpFileName 'curvdata.mat']);
    
    %Process displacement data
    data(1:length(data)/2,:)=[];     %Remove first half of simulation
    dispx=data(:,2:3:end);           %In-line displacement
    nnod=length(dispx(1,:));         %Read the number of nodes
    cord=L/(nnod-1)*[0:nnod-1];      %Establish length coordinates along the riser 
%   dispy=data(:,3:3:end);           %Axial displacement, not considered
    dispz=data(:,4:3:end);           %Cross flow displacement
    time=data(:,1)-data(1,1);        %Establish time 
    ns=length(time);                 %Number of data points
    dt=time(3)-time(2);              %Time step of sample
    Fs=1/dt;                         %Sampling frequency
    
    %Read curvature
    curvdata(1:length(curvdata)/2,:)=[]; %Remove first half of the simulation
    curvy=curvdata(:,2:4:end);           %CF curvature
    curvz=curvdata(:,4:4:end);           %IL curvature
    nnodc=length(curvy(1,:));
    cordc=L/(nnodc-1)*[0:nnodc-1];
    
    
    % remove mean value
    for inod=1:nnod
        dispx(:,inod)=dispx(:,inod)-mean(dispx(:,inod));
%       dispy(:,inod)=dispy(:,inod)-mean(dispy(:,inod));
        dispz(:,inod)=dispz(:,inod)-mean(dispz(:,inod));
    end
    
    
   % standard deviation
    dispxstd=std(dispx); %IL displacement
    dispzstd=std(dispz); %CF displacement
    curvzstd=std(curvz); %IL curvature
    curvystd=std(curvy); %CF curvature
    
    %Set directory where plots are stored
    cd(['C:\Users\dreng\OneDrive\Dokumenter\NTNU\Riflex_run\Inputfile\STRAKES\NewCDsims\OnlyQuadDamp\Strakespresenceaccounted(H)\PostprocessingBAREPARTFREQS'])
    
    %% spectrum of disp/curv at sensor 5, 19 and 36 location in NDP experiment
    %Find coordinates of NDP sensors
    cordSpec1=cordsIL(1);   %Position of first IL sensor
    cordSpec2=cordsIL(2);   %Position of first CF sensor (Fewer CF sensors than IL sensors!)
    cordSpec40=cordsIL(40); %Position of last IL and CF sensor. First and last sensor positions are needed to only compute the mean stress etc from the region with sensors
    cordSpec5=cordacc(1);   %Position of sensor 5
    cordSpec19=cordacc(4);  %Position of sensor 19
    cordSpec36=cordacc(8);  %Position of sensor 36
    
    %Find spectra of unfiltered displacement and curvature
    [Spcix,fx,Nhix]=spec(dispx(:,round(cordSpec19/L*nnod)),ns,Fs); %IL displacement
    [Spcix5,fx5,Nhix5]=spec(dispx(:,round(cordSpec5/L*nnod)),ns,Fs);
    [Spcix36,fx36,Nhix36]=spec(dispx(:,round(cordSpec36/L*nnod)),ns,Fs); 
    [Spciz,fz,Nhiz]=spec(dispz(:,round(cordSpec19/L*nnod)),ns,Fs); %CF displacement
    [Spciz5,fz5,Nhiz5]=spec(dispz(:,round(cordSpec5/L*nnod)),ns,Fs);
    [Spciz36,fz36,Nhiz36]=spec(dispz(:,round(cordSpec36/L*nnod)),ns,Fs);
    [Spccz,f_cz,Nhi_cz]=spec(curvz(:,round(cordSpec19/L*nnodc)),ns,Fs); %IL curvature
    [Spccz5,f_cz5,Nhi_cz5]=spec(curvz(:,round(cordSpec5/L*nnodc)),ns,Fs);
    [Spccz36,f_cz36,Nhi_cz36]=spec(curvz(:,round(cordSpec36/L*nnodc)),ns,Fs);
    [Spccy,f_cy,Nhi_cy]=spec(curvy(:,round(cordSpec19/L*nnodc)),ns,Fs); %CF curvature
    [Spccy5,f_cy5,Nhi_cy5]=spec(curvy(:,round(cordSpec5/L*nnodc)),ns,Fs);
    [Spccy36,f_cy36,Nhi_cy36]=spec(curvy(:,round(cordSpec36/L*nnodc)),ns,Fs);
    
   
%% ------------------Band-pass filtering-----------------------------------------
  %Define cut-off frequencies
    hpCF = 0.5; %Hz
    lpCF = 1.5*fdom_measCF(ic); 
    hpIL = 0.5*fdom_measCF(ic); 
    lpIL = 2.5*fdom_measCF(ic); 
    
%Consider the fundamental frequencies, 1xomega and 2xomega
 dispx_filtered = bpass(dispx,dt,hpIL,lpIL); %Bandpass IL displacement
 dispz_filtered = bpass(dispz,dt,hpCF,lpCF); %Bandpass CF displacement
 curvz_filtered = bpass(curvz,dt,hpIL,lpIL); %Bandpass IL curvature
 curvy_filtered = bpass(curvy,dt,hpCF,lpCF); %Bandpass CF curvature

%% Standard deviation of filtered properties
stddispx_filtered = std(dispx_filtered);           %Standard deviation of in-line filtered displacement
stddispz_filtered = std(dispz_filtered);           %Standard deviation of cross-flow filtered displacement
stdcurvz_filtered = std(curvz_filtered);           %Standard deviation of in-line filtered curvature
stdcurvy_filtered = std(curvy_filtered);           %Standard deviation of cross-flow filtered curvature
[maxSTDdispx, inddispIL] = max(stddispx_filtered); %Find position of max in-line displacement 
[maxSTDdispz, inddispCF] = max(stddispz_filtered); %Find position of max cross-flow displacement 
[maxSTDcurvz, indcurvIL] = max(stdcurvz_filtered); %Find position of max in-line curvature
[maxSTDcurvy, indcurvCF] = max(stdcurvy_filtered); %Find position of max cross-flow curvature

%% Displacement and curvature spectra of filtered properties  at sensor 5, 19 and 36 location, as well as at position of max response in NDP experiments
[Spcix_filtered,f_filteredx,Nhi_filteredx]=spec(dispx_filtered(:,round(cordSpec19/L*nnod)),ns,Fs); %Spectrum of filtered IL displacement
[Spcix_filtered5,f_filteredx5,Nhi_filteredx5]=spec(dispx_filtered(:,round(cordSpec5/L*nnod)),ns,Fs);
[Spcix_filtered36,f_filteredx36,Nhi_filteredx36]=spec(dispx_filtered(:,round(cordSpec36/L*nnod)),ns,Fs);
[Spcix_filteredmax, f_filteredxmax, Nhi_filteredxmax]=spec(dispx_filtered(:,inddispIL),ns,Fs);
[Spciz_filtered,f_filteredz,Nhi_filteredz] = spec(dispz_filtered(:,round(cordSpec19/L*nnod)),ns,Fs); %Spectrum of filtered CF displacement
[Spciz_filtered5,f_filteredz5,Nhi_filteredz5]=spec(dispz_filtered(:,round(cordSpec5/L*nnod)),ns,Fs); 
[Spciz_filtered36,f_filteredz36,Nhi_filteredz36]=spec(dispz_filtered(:,round(cordSpec36/L*nnod)),ns,Fs); 
[Spciz_filteredmax, f_filteredzmax, Nhi_filteredzmax]=spec(dispz_filtered(:,inddispCF),ns,Fs);
[Spccz_filtered,f_cfilteredz,Nhi_cfilteredz]=spec(curvz_filtered(:,round(cordSpec19/L*nnodc)),ns,Fs); %Spectrum of filtered IL curvature
[Spccz_filtered5,f_cfilteredz5,Nhi_cfilteredz5]=spec(curvz_filtered(:,round(cordSpec5/L*nnodc)),ns,Fs);
[Spccz_filtered36,f_cfilteredz36,Nhi_cfilteredz36]=spec(curvz_filtered(:,round(cordSpec36/L*nnodc)),ns,Fs);
[Spccz_filteredmax, f_cfilteredzmax, Nhi_cfilteredzmax]=spec(curvz_filtered(:,indcurvIL),ns,Fs);
[Spccy_filtered,f_cfilteredy,Nhi_cfilteredy]=spec(curvy_filtered(:,round(cordSpec19/L*nnodc)),ns,Fs); %Spectrum of filtered CF curvature
[Spccy_filtered5,f_cfilteredy5,Nhi_cfilteredy5]=spec(curvy_filtered(:,round(cordSpec5/L*nnodc)),ns,Fs);
[Spccy_filtered36,f_cfilteredy36,Nhi_cfilteredy36]=spec(curvy_filtered(:,round(cordSpec36/L*nnodc)),ns,Fs);
[Spccy_filteredmax, f_cfilteredymax, Nhi_cfilteredymax]=spec(curvy_filtered(:,indcurvCF),ns,Fs);

%Read off peak frequencies in curvature spectra at position of max response
[valuemaxIL, indILmax]=max(Spccz_filteredmax); 
[valuemaxCF, indCFmax]=max(Spccy_filteredmax);
fdomIL(ic) = f_cfilteredzmax(indILmax); 
fdomCF(ic) = f_cfilteredymax(indCFmax); 

%% Plot displacement spectra at three locations along riser, both filtered and unfiltered signals
    figure
    subplot(2,2,1)
    plot(fx5(1:Nhix5),Spcix5(1:Nhix5),fx(1:Nhix),Spcix(1:Nhix),fx36(1:Nhix36),Spcix36(1:Nhix36))
    xlim([0 30])
    ylabel('Disp. power spectrum (m^{2}s)')
    xlabel('Frequency (Hz)')
    grid on
    legend('Sensor 5', 'Sensor 19', 'Sensor 36') 
    title('Unfiltered IL')
    subplot(2,2,2)
    plot( fz5(1:Nhiz5),Spciz5(1:Nhiz5), fz(1:Nhiz),Spciz(1:Nhiz), fz36(1:Nhiz36),Spciz36(1:Nhiz36))
    xlim([0 30])
    ylabel('Disp. power spectrum (m^{2}s)')
    xlabel('Frequency (Hz)')
    grid on
    legend('Sensor 5', 'Sensor 19', 'Sensor 36') 
   title('Unfiltered CF')
    subplot(2,2,3)
    plot(f_filteredx5(1:Nhi_filteredx5),Spcix_filtered5(1:Nhi_filteredx5), f_filteredx(1:Nhi_filteredx),Spcix_filtered(1:Nhi_filteredx), f_filteredx36(1:Nhi_filteredx36),Spcix_filtered36(1:Nhi_filteredx36))
    xlim([0 30])
    ylabel('Disp. power spectrum (m^{2}s)')
    xlabel('Frequency (Hz)')
    grid on
    legend('Sensor 5', 'Sensor 19', 'Sensor 36') 
    title('Filtered IL')
    subplot(2,2,4)
     plot(f_filteredz5(1:Nhi_filteredz5),Spciz_filtered5(1:Nhi_filteredz5),f_filteredz(1:Nhi_filteredz),Spciz_filtered(1:Nhi_filteredz), f_filteredz36(1:Nhi_filteredz36),Spciz_filtered36(1:Nhi_filteredz36))
    xlim([0 30])
    ylabel('Disp. power spectrum (m^{2}s)')
    xlabel('Frequency (Hz)')
    grid on
    legend('Sensor 5', 'Sensor 19', 'Sensor 36') 
    title('Filtered CF')
    saveas(gcf,['dispspec_poscompare' inpFileName '.png']); 

   %% Plot curvature spectra at three locations along riser
    figure
    subplot(2,2,1)
    plot(f_cz5(1:Nhi_cz5),Spccz5(1:Nhi_cz5), f_cz(1:Nhi_cz),Spccz(1:Nhi_cz), f_cz36(1:Nhi_cz36),Spccz36(1:Nhi_cz36))
    xlim([0 30])
    ylabel('IL curv. ')
    xlabel('Frequency (Hz)')
    grid on
    legend('Sensor 5', 'Sensor 19', 'Sensor 36') 
    title(['Unf IL curv' inpFileName])
    subplot(2,2,2)
    plot(f_cy5(1:Nhi_cy5),Spccy5(1:Nhi_cy5), f_cy(1:Nhi_cy),Spccy(1:Nhi_cy), f_cy36(1:Nhi_cy36),Spccy36(1:Nhi_cy36))
    xlim([0 30])
    ylabel('CF curv. ')
    xlabel('Frequency (Hz)')
    grid on
    legend('Sensor 5', 'Sensor 19', 'Sensor 36') 
    title('Unf CF curv')
    subplot(2,2,3)
    plot(f_cfilteredz5(1:Nhi_cfilteredz5),Spccz_filtered5(1:Nhi_cfilteredz5), f_cfilteredz(1:Nhi_cfilteredz),Spccz_filtered(1:Nhi_cfilteredz), f_cfilteredz36(1:Nhi_cfilteredz36),Spccz_filtered36(1:Nhi_cfilteredz36) ) 
    xlim([0 30])
    ylabel('IL curv. ')
    xlabel('Frequency (Hz)')
    grid on
    legend('Sensor 5', 'Sensor 19', 'Sensor 36') 
    title(['Fil IL curv' inpFileName])
    subplot(2,2,4)
    plot(f_cfilteredy5(1:Nhi_cfilteredy5),Spccy_filtered5(1:Nhi_cfilteredy5), f_cfilteredy(1:Nhi_cfilteredy),Spccy_filtered(1:Nhi_cfilteredy), f_cfilteredy36(1:Nhi_cfilteredy36),Spccy_filtered36(1:Nhi_cfilteredy36) ) 
    xlim([0 30])
    ylabel('CF curv. ')
    xlabel('Frequency (Hz)')
    grid on
    legend('Sensor 5', 'Sensor 19', 'Sensor 36') 
    title('Fil CF curv')    
    saveas(gcf,['curvspec_' inpFileName '.png']); 
    
    %% Plot the curvature spectra at the position of max response
    figure 
    subplot(2,1,1)
    plot(f_cfilteredzmax(1:Nhi_cfilteredzmax),Spccz_filteredmax(1:Nhi_cfilteredzmax))
    xlim([0 30])
    ylabel('IL curv. ')
    xlabel('Frequency (Hz)')
    grid on
    title(['IL curv' inpFileName])
    subplot(2,1,2)
    plot(f_cfilteredymax(1:Nhi_cfilteredymax),Spccy_filteredmax(1:Nhi_cfilteredymax))
    xlim([0 30])
    ylabel('CF curv. ')
    xlabel('Frequency (Hz)')
    grid on 
    title('CF curv')    
    saveas(gcf,['curvspecmax_' inpFileName '.png']); 
    
    %% Time series of displacement and curvature at sensor19 of NDP experiments
    figure
    subplot(2,1,1)
    plot(time,dispx(:,round(cordSpec19/L*nnod)),time,dispz(:,round(cordSpec19/L*nnod)), time, dispx_filtered(:,round(cordSpec19/L*nnod)))
    legend('IL','CF', 'IL filtered', 'Location', 'Best')  
    xlabel('Time (s)') 
    ylabel('Displacement (m)') 
    title(['Time series at sensor19:' inpFileName Cvs])
    subplot(2,1,2)
    plot(time,curvz(:,round(cordSpec19/L*nnodc)),time,curvy(:,round(cordSpec19/L*nnodc)),time,curvz_filtered(:,round(cordSpec19/L*nnodc)))
    legend('IL','CF', 'IL filtered', 'Location', 'Best')
    xlabel('Time (s)') 
    ylabel('Curvature (1/m)') 
    saveas(gcf,['disptime_' inpFileName '.png']);
    

     %% std/D along pipe
    figure
    plot(cord, stddispz_filtered/D,'b',cordacc, disp_measCF(ic,:),'bo', cord, stddispx_filtered/D,'r',  cordacc, disp_measIL(ic,:),'ro')
    legend('Sim CF','Exp CF', 'Sim IL', 'Exp','Location','Best')
    xlabel('Length (m)')
    ylabel('\sigma_{disp}/D (-)')
    grid on
    saveas(gcf,['dispAD_' inpFileName '.png']);
    saveas(gcf,['dispAD_' inpFileName], 'epsc');

 %% Curvature std along pipe
 figure
    subplot(2,1,1)
    plot(cordc, curvystd,'b', cordc, stdcurvy_filtered,'-r')
    legend('Unfiltered','Filtered','Location','Best')
    ylabel('Cross-flow curvature std (1/m)')
    xlabel('Length (m)')
    grid on
 %   title(['CF curv:' inpFileName])
    subplot(2,1,2) 
    plot(cordc,curvzstd,'b', cordc, stdcurvz_filtered,'-r')
    legend('Unfiltered','Filtered','Location','Best')
    ylabel('In-line curvature std (1/m)')
    xlabel('Length (m)')
    grid on
  %  title('IL curv') 
    saveas(gcf,['curvstd_' inpFileName '.png']);

    
  %% Find mean of std of displacements
%Mean of std of in-line filtered displacement (between first and last accelerometer)  
MeanSTDDispsimIL(ic) = mean(stddispx_filtered(round(cordSpec5/L*nnod):round(cordSpec36/L*nnod))/D); %Predicted
meandisp_measIL(ic) = mean(disp_measIL(ic,:)); %Measured
%Mean of std of cross-flow filtered displacement (between first and last accelerometer)
MeanSTDDispsimCF(ic) = mean(stddispz_filtered(round(cordSpec5/L*nnod):round(cordSpec36/L*nnod))/D); %Predicted
meandisp_measCF(ic) = mean(disp_measCF(ic,:)); %Measured
    

    %%  Fatigue calculation
    % SN curve parameters
    m0=3;
    K0=10^(-11.63);
     
    
    % Bending stress (MPa) cross-flow and in-line
    SsimCF=E*curvy_filtered*D/2*1e-6;      %Cross-flow (at 90deg)  
    %Standard deviation and mean of standard deviation between first and
    %last CF strain gauge
    StdSsimCF=std(SsimCF);
    meanSTDSsimCF(ic)=mean(StdSsimCF(round(cordSpec2/L*nnodc):round(cordSpec40/L*nnodc)));  
    
    SsimIL=E*curvz_filtered*D/2*1e-6;      %In-line (at 0deg)
    %Standard deviation and mean of standard deviation between first and
    %last IL strain gauge
    StdSsimIL=std(SsimIL); 
    meanSTDSsimIL(ic)=mean(StdSsimIL(round(cordSpec1/L*nnodc):round(cordSpec40/L*nnodc))); 


     
    % Rain-flow counting
    [p,q]=size(SsimCF);
    for i=1:q
        Ss_tpCF=dat2tp(SsimCF(:,i)); %Find turning points in stress time series
        Ss_tpIL=dat2tp(SsimIL(:,i));
        Ss_rfcCF=tp2rfc(Ss_tpCF); %Find rainflow stress cycles
        Ss_rfcIL=tp2rfc(Ss_tpIL);
        fs_rfcfdCF(i)=cc2dam(Ss_rfcCF,m0,K0)*2^m0/(ns*dt)*3600*24*365;    % yearly fatigue damage
        fs_rfcfdIL(i)=cc2dam(Ss_rfcIL,m0,K0)*2^m0/(ns*dt)*3600*24*365;
    end
    
%Find predicted maximum fatigue along riser cross-flow and in-line. Consider the region of the riser with sensors
    maxfat_predCF(ic)=max(fs_rfcfdCF(round(cordSpec2/L*nnodc):round(cordSpec40/L*nnodc)));
    maxfat_predIL(ic)=max(fs_rfcfdIL(round(cordSpec1/L*nnodc):round(cordSpec40/L*nnodc)));
    maxfatRateCF(ic) = maxfat_predCF(ic)/maxfat_measCF(ic); 
    maxfatRateIL(ic) = maxfat_predIL(ic)/maxfat_measIL(ic); 
%Find predicted mean fatigue along riser cross-flow and in-line. Consider the region of the riser with sensors
    meanfat_predCF(ic)=mean(fs_rfcfdCF(round(cordSpec2/L*nnodc):round(cordSpec40/L*nnodc))); 
    meanfat_predIL(ic)=mean(fs_rfcfdIL(round(cordSpec1/L*nnodc):round(cordSpec40/L*nnodc))); 
    
%% Plot stress std along riser
    figure
    subplot(2,1,1)
    plot(cordc,StdSsimCF,'b-',cordsCF,stress_measCF(ic,:),'ro')
    grid on
    legend('Sim','Exp', 'Location', 'Best')
    ylabel('Stress std (Mpa)')
    xlabel('Length (m)')
    title('Cross-flow') 
    subplot(2,1,2)
    plot(cordc,StdSsimIL,'b-',cordsIL,stress_measIL(ic,:),'ro')
    grid on 
    legend('Sim','Exp', 'Location', 'Best') 
    ylabel('Stress std (MPa)') 
    xlabel('Length (m)')
    title('In-line')
    saveas(gcf,['stress_' inpFileName  '.png']);
    saveas(gcf,['stress_' inpFileName], 'epsc');

    %% Plot fatigue along riser
    figure
    subplot(2,1,1)
    plot(cordc,log10(fs_rfcfdCF),'b-',cordsCF,log10(fat_measCF(ic,:)),'ro')
    grid on
    legend('Sim','Exp','Location','Best')
    ylabel('log10(Damage) (1/yrs) ')
    xlabel('Length (m)')
    title('Cross-flow')
    xlim([1,37.5])
    subplot(2,1,2)
    plot(cordc,log10(fs_rfcfdIL),'b-',cordsIL,log10(fat_measIL(ic,:)),'ro')
    grid on 
    legend('Sim', 'Exp', 'Location', 'Best')
    ylabel('log10(Damage) (1/yrs) ')
    xlabel('Length (m)') 
    xlim([1,37.5]) 
    title('In-line')
    saveas(gcf,['fat_' inpFileName '.png']);
    saveas(gcf,['fat_' inpFileName], 'epsc');
end

%% Plot comparison of max fatigue for experiment and simulation as function of current speed
figure 
subplot(1,2,1)
plot(U_meas(simcases),log10(maxfat_predCF(simcases))','bs',U_meas(allcases),log10(maxfat_measCF(allcases)),'ro')
grid on
legend('Sim','Exp','Location','Best')
ylabel('log10(Max fatigue) (1/yrs) ')
xlabel('Current speed (m/s)')
title('Cross-flow')
%title(['Max fatigue damage comparison: NDP38m' curr 'flow' Cvs])
subplot(1,2,2)
plot(U_meas(simcases),log10(maxfat_predIL(simcases))','bs',U_meas(allcases),log10(maxfat_measIL(allcases)),'ro')
grid on
legend('Sim','Exp','Location','Best')
ylabel('log10(Max fatigue) (1/yrs) ')
xlabel('Current speed (m/s)')
title('In-line')
saveas(gcf,['maxfat_' curr '.png']);
saveas(gcf,['maxfat_' curr], 'epsc');

%% Plot comparison of mean fatigue for experiment and simulation as function of current speed
figure
subplot(1,2,1)
plot(U_meas(simcases),log10(meanfat_predCF(simcases))','bs',U_meas(allcases),log10(meanfat_measCF(allcases)),'ro')
grid on
legend('Sim','Exp','Location','Best')
ylabel('log10(Mean fatigue) (1/yrs) ')
xlabel('Current speed (m/s)')
title('Cross-flow')
%title(['Mean fatigue damage comparison: NDP38m' curr 'flow' Cvs])
subplot(1,2,2) 
plot(U_meas(simcases),log10(meanfat_predIL(simcases))','bs',U_meas(allcases),log10(meanfat_measIL(allcases)),'ro')
grid on
legend('Sim','Exp','Location','Best')
ylabel('log10(Mean fatigue) (1/yrs) ')
xlabel('Current speed (m/s)')
title('In-line')
saveas(gcf,['meanfat_' curr '.png']);
saveas(gcf,['meanfat_' curr], 'epsc');


%% Plot dominating strain/curvature/stress frequency at position of max response
figure
subplot(1,2,1)
plot(U_meas(simcases),fdomCF(simcases),'bs',U_meas(allcases),fdom_measCF(allcases),'ro')
grid on 
legend('Sim','Exp', 'Location', 'Best')
ylabel('Dominating frequency (Hz) ')
xlabel('Current speed (m/s)')
title('Cross-flow')
%title(['Dominating frequency comparison: NDP38m' curr 'flow' Cvs])
subplot(1,2,2) 
plot(U_meas(simcases),fdomIL(simcases),'bs',U_meas(allcases),fdom_measIL(allcases),'ro')
grid on
legend('Sim','Exp', 'Location', 'Best')
ylabel('Dominating frequency (Hz) ')
xlabel('Current speed (m/s)')
title('In-line')
saveas(gcf,['FreqStrain_NDPmaxpos' curr '.png']);
saveas(gcf,['FreqStrain_NDPmaxpos' curr], 'epsc');


%% Plot mean stress std as function of current speed
figure 
subplot(1,2,1)
plot(U_meas(simcases),meanSTDSsimCF(simcases),'bs', U_meas(allcases), meanstress_measCF(allcases), 'ro')
grid on
legend('Sim','Exp', 'Location', 'Best')
ylabel('Mean std of stress (MPa) ')
xlabel('Current speed (m/s)')
title('Cross-flow')
subplot(1,2,2) 
plot(U_meas(simcases),meanSTDSsimIL(simcases),'bs',U_meas(allcases),meanstress_measIL(allcases),'ro')
grid on
legend('Sim','Exp', 'Location', 'Best')
ylabel('Mean std of stress (MPa)')
xlabel('Current speed (m/s)')
title('In-line')
saveas(gcf,['MeanstdStress' curr '.png']);
saveas(gcf, ['MeanstdStress' curr], 'epsc');

%% Plot mean std of displacement as function of current speed
figure 
plot(U_meas(simcases),MeanSTDDispsimCF(simcases),'bs-', U_meas(allcases), meandisp_measCF(allcases), 'bo', U_meas(simcases),MeanSTDDispsimIL(simcases),'rs-',U_meas(allcases),meandisp_measIL(allcases),'ro')
grid on
legend('Sim CF','Exp CF', 'Sim IL','Exp IL', 'Location', 'Best')
ylabel('\sigma_{disp}/D (-) ')
xlabel('Current speed (m/s)')
saveas(gcf,['MeanstdDisp' curr '.png']);
saveas(gcf, ['MeanstdDisp' curr], 'epsc');

save('maxfatRateShear','maxfatRateCF','maxfatRateIL')
 save(['maxFatigue' curr],'maxfat_predCF','maxfat_predIL','maxfat_measCF','maxfat_measIL')
save('domfreqs','fdomCF','fdomIL')