%%This script is used for loading and saving the processed experimental NDP 
%%data for bare risers from an excel-file and a mat-file, as well as simulating selected
%%cases and storing the simulation output. 

clear all
close all
%% Pipe property
D=0.027;        %Pipe diameter
L=38;           %Pipe length
E=36.2e9;       %Elastic modulus
nnod = 502;     %Number of nodes
nelem = nnod-2; %Number of elements
%% Load measured fatigue, displacement and stress
MeasPath=['C:\Users\dreng\OneDrive\Dokumenter\NTNU\Riflex_run\Meas\']; 
MeasData=importdata([MeasPath 'bare_1w.xlsx']); %Read NDP data from excel sheet
MatMeasPath=['C:\Users\dreng\OneDrive\Dokumenter\NTNU\Riflex_run\High Mode VIV Model tests\Raw data\'];
MatMeasData=load([MatMeasPath 'nakedmeasdata1w.mat']); %Read NDP data from generated mat-files

%Coordinates for measured strains, CF and IL
cordsCF=[2.555	3.084	3.224	4.155	6.030	8.609	8.889	10.285	13.676	16.452	16.891	19.997 ...
        20.193	21.393	22.460	23.165	25.153	26.254	28.863	29.365	31.191	33.005	36.559	37.322];
cordsIL=[1.143 2.555 3.084 3.224 4.155 5.759 6.030 7.664 8.216 8.609 8.889 9.703 10.285 13.676 13.772 ...
        15.393 16.452 16.547 16.891 16.997 20.193 21.393 21.603 22.460 23.165 25.153 25.442 26.254 ...
        27.532 28.698 28.863 29.365 31.191 31.415 32.796 33.005 35.549 36.559 36.824 37.322];
    
%Coordinates for measured displacments, same IL and CF    
cordacc=[4.155 8.609 13.676 16.891 21.393 25.153 28.863 33.005]; 
cordSpec=cordacc(4); 

%Read data from excel sheet
CaseID=MeasData.data.AD(2:end,1);   %CaseID for all cases
U_meas=MeasData.data.AD(2:end,2);   %Current speed for all cases [m/s]
Ten=MeasData.data.INFO(1:end,10);   %Mean effective tension [N]

%Read data from mat-file
fat_measCF=MatMeasData.fs_rfcfd2CF; %CF fatigue at 1xomega 
maxfat_measCF=max(fat_measCF,[],2); %Max CF fatigue alomg riser
meanfat_measCF=mean(fat_measCF,2);  %Mean CF fatigue along riser

fat_measIL=MatMeasData.fs_rfcfdIL2; %IL fatigue at 2xomega
maxfat_measIL=max(fat_measIL,[],2); %Max IL fatigue along riser
meanfat_measIL=mean(fat_measIL,2);  %Mean IL fatigue along riser

disp_measCF=MatMeasData.ADy2;  %CF displacement std (1xomega)
disp_measIL=MatMeasData.ADx2;  %IL displacement std (2xomega)

stress_measCF=MatMeasData.stdSsCF2;      %CF stress std
meanstress_measCF=mean(stress_measCF,2); %Mean CF stress std along riser
stress_measIL=MatMeasData.stdSsIL2;      %IL stress std
meanstress_measIL=mean(stress_measIL,2); %Mean CF stress std along riser

fdom_measCF=MatMeasData.fdomsCF(:,4); % Dominating measured strain frequency CF at sensor 5/19/36/max curv repsonse (column 1/2/3/4)
fdom_measIL=MatMeasData.fdomsIL(:,4); %Dominating measured strain frequency IL at sensor 5/19/36/max curv response
fdom_measdCF=MatMeasData.fdomCF(:,3); %Dominating measured displacement frequency CF at sensor 5/19/36
fdom_measdIL=MatMeasData.fdomIL(:,3); %Dominating measured displacement frequency IL at sensor 5/19/36

save([MeasPath 'measdata.mat'])

load([MeasPath 'measdata.mat']);

%% Provide parameters for input-files
% TDVIV hydrodynamic parameters
cqx = 0;                  %Quadratic drag coefficient in tangential direction
cqy = 0.9;                %Quadratic drag coefficient in normal direction
cax = 0;                  %Added mass per unit length in tangential direction
cay = 1;                  %Added mass per unit length in normal direction
clx = 0;                  %Linear drag force coefficient in tangential direction
cly = 0;                  %Linear drag force coefficient in normal direction
icode = 2;                %Code for giving nondimensional hydrodynamic coefficients as input
scfkn = 1;                %Froude-Kriloff scaling term
Cv= 0.85;                 %Vortex shedding force coefficient
CVIL=zeros(length(Cv),1); %In-line excitation coefficient (preallocated to 0, was a vector during the calibration)
CvRes=1.3;                %Resultant of Cv and CVIL
FNUL= 0.144;              %Natural vortex shedding frequency
FMIN= 0.08;               %Minimum vortex shedding frequency
FMAX= 0.208;              %Maximum vortex shedding frequency
NMEM=500;                 %Number of time steps used in calculation of standard deviation
ALPHIL=0.15;              %Dimensionless parameter giving freedom to in-line excitation frequency
CHH=0;                    %Dimensionless parameter giving freedom to in-line excitation frequency

%Regular wave data (to be printed to inpmod)
inrwc = 1; 
amplit = 10^-9; 
wavdir = 0; 

for icv = 1:length(Cv)
CVIL(icv) = sqrt((CvRes^2-Cv(icv)^2)); %Find CVIL from Pythagorean relation between Cv and CvRes
Cvs = num2str(Cv(icv));                %Convert number to string. Was needed to separate plots with different Cv during calibration

%% Read template file 
templatePath='C:\Users\dreng\OneDrive\Dokumenter\NTNU\Riflex_run\Template';
inpfilePath='C:\Users\dreng\OneDrive\Dokumenter\NTNU\Riflex_run\Inputfile';

tempFileName='ndp38m0';


simcases = 23; %Cases selected for simulation, numbers refer to how the cases are listed in CaseID.
allcases = 23:1:44; %Vector including all uniform or shear flow cases, different than simcases if a limited number of cases are simulated
                    %Uniform flow cases: 23:1:44;
                    %Shear flow cases: 1:1:22;
for ic=simcases
    inpFileName=['ndp38m' num2str(CaseID(ic))]; 
    tempInpmod = fileread([templatePath '\\' tempFileName '_inpmod.inp']);    %Read the template input file
    tempInpmod = strjoin(strsplit(tempInpmod,'\r\n'),'\n');                   %Split read string at specified delimiter
    tempStamod = fileread([templatePath '\\' tempFileName '_stamod.inp']);    %Read the template input file
    tempStamod = strjoin(strsplit(tempStamod,'\r\n'),'\n');                   %Split read string at specified delimiter
    tempDynmod = fileread([templatePath '\\' tempFileName '_dynmod.inp']);    %Read the template input file
    tempDynmod = strjoin(strsplit(tempDynmod,'\r\n'),'\n');                   %Split read string at specified delimiter
    
    %Define hydrodynamic parameters
    %            'cqx cqy cax cay clx cly icode D scfkn CV       FNUL FMIN  FMAX NMEM  CVIL      ALPHIL   CHH
    data=num2str([cqx cqy cax cay clx cly icode D scfkn Cv(icv)  FNUL FMIN FMAX   NMEM CVIL(icv) ALPHIL CHH]);
    caseInp = strrep(tempInpmod, '_HYDR_PARA_',data);             %Replace the contents _HYDR_PARA_ in the original file with new contents
    tempInpmod = caseInp; 
    
    %Define time step by the measured CF period for each case. Defined in dynmod: 40 time
    %steps per CF period, 400 CF periods simulated
    CF_period=1/fdom_measCF(ic); 
    %              'inrwc amplit   period      wavdir          
    data = num2str([inrwc amplit   CF_period   wavdir]); 
    caseInp = strrep(tempInpmod, '_PERIODDATA_', data);               %Replace the contents _PERIODDATA_ in the original file with new contents
    fid = fopen([inpfilePath '\\' inpFileName '_inpmod.inp'],'wt');   %Write in the file
    fprintf(fid, '%s', caseInp);
    fclose(fid);
    
    %Define tension
    xxxTen=Ten(ic)/1000;  % kN
    %     'line-id            ilseg  ilnode   ildof  rlmag       chicoo
    data=['line1   ' num2str( [2     nnod/2      2   xxxTen]) '  GLOBAL'];
    caseInp = strrep(tempStamod, '__TEN__',data);                           %Replace the contents __TEN__ in the original file with new contents
    tempStamod = caseInp;

    %Define current
    %' nlcomp  icurin  curfac  iwindin
    xxxCur=U_meas(ic);
    if ic<23
        data=num2str([1  2 xxxCur 0]);  %Sheared profile
        curr = 'Shear';
    else             
        data=num2str([1  1 xxxCur 0]);  %Uniform profile
        curr = 'Uniform'; 
    end
    caseInp = strrep(tempStamod, '__CURR__',data);                    %Replace the contents __CURR__ in the original file with new contents
    fid = fopen([inpfilePath '\\' inpFileName '_stamod.inp'],'wt');   %Write in the file
    fprintf(fid, '%s', caseInp);
    fclose(fid);
    
    %Copy dynmod file, no replacement of the content
    fid = fopen([inpfilePath '\\' inpFileName '_dynmod.inp'],'wt');   %Write in the file
    fprintf(fid, '%s', tempDynmod);
    fclose(fid);
    
    %Run VIVANA-TD
    res(ic)=riflex('isd',inpfilePath, inpFileName);
    
    %% Extract and store TD analysis results
    cd(['C:\Users\dreng\OneDrive\Dokumenter\NTNU\Riflex_run\Inputfile\BARE\Simulations\INSPERAFILECHECK']) %Directory for storing simulation data
    data=load([inpfilePath '\' inpFileName '_noddis.asc']);             %Displacement data
    curvdata=load([inpfilePath '\' inpFileName '_elmcur.asc']);         %Curvature data
    save([inpFileName Cvs 'dispdata.mat'],'data');                      %Store displacement data in mat-files
    load([inpFileName Cvs 'dispdata.mat']);                            %Load displacement data
    save([inpFileName Cvs 'curvdata.mat'],'curvdata');                  %Store curvature data in mat-files
    load([inpFileName Cvs 'curvdata.mat']);                             %Load cruvature data
    
    %% Process and plot simulation data vs measured data
%Process displacement data
    data(1:length(data)/2,:)=[]; %Remove first half of simulation
    dispx=data(:,2:3:end);       %In-line displacement
    nnod=length(dispx(1,:));     %Read the number of nodes
    cord=L/(nnod-1)*[0:nnod-1];  %Establish length coordinates along the riser 
%   dispy=data(:,3:3:end);       %Axial displacement, not considered
    dispz=data(:,4:3:end);       %Cross-flow displacement
    time=data(:,1)-data(1,1);    %Establish time 
    ns=length(time);             %Number of data points
    dt=time(3)-time(2);          %Time step of sample
    Fs=1/dt;                     %Sampling frequency
    
    %Read curvature
    curvdata(1:length(curvdata)/2,:)=[]; %Remove first half of the simulation
    curvy=curvdata(:,2:4:end);           %Cross-flow curvature
    curvz=curvdata(:,4:4:end);           %In-line curvature
    nnodc=length(curvy(1,:));            %Read the number of curvature data points
    cordc=L/(nnodc-1)*[0:nnodc-1];       %Establish length coordinates along riser
    
    
    %Remove mean value
    for inod=1:nnod
        dispx(:,inod)=dispx(:,inod)-mean(dispx(:,inod));
%       dispy(:,inod)=dispy(:,inod)-mean(dispy(:,inod));
        dispz(:,inod)=dispz(:,inod)-mean(dispz(:,inod));
    end
    
    %Standard deviation
    dispzstd=std(dispz);
    dispxstd=std(dispx);
    
    
    
    % Spectrum of disp/curv at sensor 19 location in NDP experiment, NOT
    % filtered. Used for comparing with filtered results, as well as
    % finding dominating frequency CF
    [Spcix,fx,Nhix]=spec(dispx(:,round(cordSpec/L*nnod)),ns,Fs); %IL displacement
    [Spciz,fz,Nhiz]=spec(dispz(:,round(cordSpec/L*nnod)),ns,Fs); %CF displacement
    [Spccz,f_cz,Nhi_cz]=spec(curvz(:,round(cordSpec/L*nnodc)),ns,Fs); %IL curvature
    [Spccy,f_cy,Nhi_cy]=spec(curvy(:,round(cordSpec/L*nnodc)),ns,Fs); %CF curvature

%% ------------------Band-pass filtering-----------------------------------------
%Consider the fundamental frequencies, 1xomega and 2xomega
 dispx_filtered = bpass(dispx,dt,0.5*fdom_measCF(ic),2.5*fdom_measCF(ic)); %Bandpass IL displacement, from 1.5xomega to 12.5xomega
 dispz_filtered = bpass(dispz,dt,0.5,1.5*fdom_measCF(ic)); %Bandpass CF displacement, from 0.5xomega to 1.5xomega
 curvz_filtered = bpass(curvz,dt,0.5*fdom_measCF(ic),2.5*fdom_measCF(ic)); %Bandpass IL curvature, from 1.5xomega to 12.5xomega
 curvy_filtered = bpass(curvy,dt,0.5,1.5*fdom_measCF(ic)); %Bandpass CF curvature, from 0.5xomega to 1.5xomega
 
%Standard deviation of filtered properties
stddispx_filtered = std(dispx_filtered); %In-line filtered displacement

%Spectra at sensor 19 location from NDP experiments of filtered properties 
[Spcix_filtered,f_xfiltered,Nhi_xfiltered]=spec(dispx_filtered(:,round(cordSpec/L*nnod)),ns,Fs);    %Spectrum of filtered IL displacement
[Spciz_filtered,f_zfiltered,Nhi_zfiltered]=spec(dispz_filtered(:,round(cordSpec/L*nnod)),ns,Fs);                      %Spectrum of filtered CF displacement
[Spccz_filtered,f_czfiltered,Nhi_czfiltered]=spec(curvz_filtered(:,round(cordSpec/L*nnodc)),ns,Fs); %Spectrum of filtered IL curvature
[Spccy_filtered,f_cyfiltered,Nhi_cyfiltered]=spec(curvy_filtered(:,round(cordSpec/L*nnodc)),ns,Fs); %Spectrum of filtered CF curvature

[valueIL, indz]=max(Spccz_filtered);   %Find value and position of peak in in-line curvature spectrum
[valueCF, indy]=max(Spccy_filtered);   %Find value and position of peak in cross-flow curvature spectrum
fdomIL(ic)=f_czfiltered(indz);         %Find dominating frequency IL.
fdomCF(ic)=f_cyfiltered(indy);         %Find dominating frequency CF    

%Plot displacement spectra
    figure
    subplot(2,2,1)
    plot(fx(1:Nhix),Spcix(1:Nhix)) 
    xlim([0 25])
    ylabel('IL disp.')
    grid on
    legend('Unfiltered') 
    title(['Displacement spectrum at sensor19:' inpFileName Cvs])
    subplot(2,2,2)
    plot(f_xfiltered(1:Nhi_xfiltered),Spcix_filtered(1:Nhi_xfiltered))
    xlim([0 26])
    ylabel('IL disp.')
    grid on
    legend('Filtered - 0.5-12.5\omega')
    subplot(2,2,3)
    plot(fz(1:Nhiz),Spciz(1:Nhiz))
    xlim([0.1 15])
    ylabel('CF disp. ')
    grid on
    xlabel('Frequency (Hz)')
    legend('Unfiltered')
    subplot(2,2,4)
    plot(f_zfiltered(1:Nhi_zfiltered),Spciz_filtered(1:Nhi_zfiltered))
    xlim([0.1 15])
    ylabel('CF disp. ')
    grid on
    xlabel('Frequency (Hz)')
    legend('Filtered - 0.5-2\omega')
    saveas(gcf,['dispspec_' inpFileName Cvs '.png']); 

    %Plot curvature spectra 
    figure
    subplot(2,1,1)
    plot(f_czfiltered(1:Nhi_czfiltered),Spccz_filtered(1:Nhi_czfiltered))
    xlim([0 25])
    legend('Filtered - ')
    title(['IL curvature spectra comparison at sensor19:' inpFileName Cvs])
    ylabel('IL curvature')
    xlabel('Frequency (Hz)')
    grid on
    subplot(2,1,2) 
    plot(f_cz(1:Nhi_cz),Spccz(1:Nhi_cz)) 
    xlim([0 25])
    legend('Unfiltered')
    ylabel('IL curvature')
    xlabel('Frequency (Hz)')
    grid on
    saveas(gcf,['curvspec_' inpFileName Cvs '.png']); 
    
    
    % Plot time series of displacement and curvature at sensor19 of NDP
    % experiments
    figure
    subplot(2,1,1)
    plot(time,dispx(:,round(cordSpec/L*nnod)),time,dispz(:,round(cordSpec/L*nnod)), time, dispx_filtered(:,round(cordSpec/L*nnod)))
    legend('IL','CF', 'IL filtered', 'Location', 'Best')
    xlabel('Time (s)') 
    ylabel('Displacement (m)') 
    title(['Time series at sensor19:' inpFileName Cvs])
    subplot(2,1,2)
    plot(time,curvz(:,round(cordSpec/L*nnodc)),time,curvy(:,round(cordSpec/L*nnodc)),time,curvz_filtered(:,round(cordSpec/L*nnodc)))
    legend('IL','CF', 'IL filtered', 'Location', 'Best')
    xlabel('Time (s)') 
    ylabel('Curvature (1/m)') 
    saveas(gcf,['disp&curvtime_' inpFileName Cvs '.png']);
    
 
    % Plot std/D along pipe
    figure
    plot(dispzstd/D,cord,'-b', disp_measCF(ic,:),cordacc,'bo', stddispx_filtered/D,cord,'-r', disp_measIL(ic,:),cordacc,'ro')
    legend('Pred. CF','Meas. CF','Pred. IL', 'Meas. IL','Location','Best')
    ylabel('Length (m)')
    xlabel('Displacement std/D (-)')
    grid on
    title(['Displacement comparison:' inpFileName Cvs])
    saveas(gcf,['dispAD_' inpFileName Cvs '.png']);

    
    %%  Fatigue calculation
    % SN curve parameters
    m0=3;
    K0=10^(-11.63);
    
    % Bending stress (MPa) cross-flow and in-line
    SsimCF=E*curvy_filtered*D/2*1e-6;  %The bending stress cross flow (at 90deg)     
    StdSsimCF=std(SsimCF);             %The cross-flow stress std
    meanSTDSsimCF(ic)=mean(StdSsimCF); %The mean of the cross-flow stress std along the riser
    
    SsimIL=E*curvz_filtered*D/2*1e-6;  %The bending stress in-line (at 0deg)
    StdSsimIL=std(SsimIL);             %The in-line stress std
    meanSTDSsimIL(ic)=mean(StdSsimIL); %The mean of the cross-flow stress std along the riser
     
    % Rain-flow counting
    [p,q]=size(SsimCF);
    for i=1:q
        Ss_tpCF=dat2tp(SsimCF(:,i)); %Find turning points in stress time series
        Ss_tpIL=dat2tp(SsimIL(:,i));
        Ss_rfcCF=tp2rfc(Ss_tpCF); %Find rainflow stress cycles
        Ss_rfcIL=tp2rfc(Ss_tpIL);
        fs_rfcfdCF(i)=cc2dam(Ss_rfcCF,m0,K0)*2^m0/(ns*dt)*3600*24*365;    %Yearly fatigue damage
        fs_rfcfdIL(i)=cc2dam(Ss_rfcIL,m0,K0)*2^m0/(ns*dt)*3600*24*365;
    end
    %Find predicted maximum fatigue along riser cross-flow and in-line
    maxfat_predCF(ic)=max(fs_rfcfdCF);
    maxfat_predIL(ic)=max(fs_rfcfdIL);

    %Find predicted mean fatigue along riser cross-flow and in-line
    meanfat_predCF(ic)=mean(fs_rfcfdCF); 
    meanfat_predIL(ic)=mean(fs_rfcfdIL); 
    
   %Plot stress standard deviation along riser
    figure
    subplot(2,1,1)
    plot(cordc,StdSsimCF,'b-',cordsCF,stress_measCF(ic,:),'ro')
    grid on
    legend('CF pred','CF meas', 'Location', 'Best')
    ylabel('Stress (Mpa)')
    xlabel('Length (m)')
    title(['Stress comparison:' inpFileName Cvs]) 
    subplot(2,1,2)
    plot(cordc,StdSsimIL,'b-',cordsIL,stress_measIL(ic,:),'ro')
    grid on 
    legend('IL pred','IL meas', 'Location', 'Best') 
    ylabel('Stress (MPa)') 
    xlabel('Length (m)') 
    saveas(gcf,['stress_' inpFileName Cvs '.png']);

    %Plot fatigue damage along riser
    figure
    subplot(2,1,1)
    plot(cordc,log10(fs_rfcfdCF),'b-',cordsCF,log10(fat_measCF(ic,:)),'ro')
    grid on
    legend('CF pred','CF meas','Location','Best')
    ylabel('log10(Fatigue damage) (1/yrs) ')
    xlabel('Length (m)')
    title(['Fatigue damage comparison:' inpFileName Cvs])
    xlim([1,40])
    subplot(2,1,2)
    plot(cordc,log10(fs_rfcfdIL),'b-',cordsIL,log10(fat_measIL(ic,:)),'ro')
    grid on 
    legend('IL pred', 'IL meas', 'Location', 'Best')
    ylabel('log10(Fatigue damage) (1/yrs) ')
    xlabel('Length (m)') 
    xlim([1,40]) 
    saveas(gcf,['fat_' inpFileName Cvs '.png']);
    
    save([inpFileName Cvs '.mat'])
end


figure 
subplot(1,2,1)
plot(U_meas(simcases),log10(maxfat_predCF(simcases))','bs',U_meas(allcases),log10(maxfat_measCF(allcases)),'ro')
grid on
legend('Sim','Exp','Location','Best')
ylabel('log10(Max fatigue) (1/yrs) ')
xlabel('Towing speed (m/s)')
title('Cross-flow')
%title(['Max fatigue damage comparison: NDP38m' curr 'flow' Cvs])
subplot(1,2,2)
plot(U_meas(simcases),log10(maxfat_predIL(simcases))','bs',U_meas(allcases),log10(maxfat_measIL(allcases)),'ro')
grid on
legend('Sim','Exp','Location','Best')
ylabel('log10(Max fatigue) (1/yrs) ')
xlabel('Towing speed (m/s)')
title('In-line')
saveas(gcf,['maxfat_' curr Cvs '.png']);


figure
subplot(1,2,1)
plot(U_meas(simcases),log10(meanfat_predCF(simcases))','bs',U_meas(allcases),log10(meanfat_measCF(allcases)),'ro')
grid on
legend('Sim','Exp','Location','Best')
ylabel('log10(Mean fatigue) (1/yrs) ')
xlabel('Towing speed (m/s)')
title('Cross-flow')
%title(['Mean fatigue damage comparison: NDP38m' curr 'flow' Cvs])
subplot(1,2,2) 
plot(U_meas(simcases),log10(meanfat_predIL(simcases))','bs',U_meas(allcases),log10(meanfat_measIL(allcases)),'ro')
grid on
legend('Sim','Exp','Location','Best')
ylabel('log10(Mean fatigue) (1/yrs) ')
xlabel('Towing speed (m/s)')
title('In-line')
saveas(gcf,['meanfat_' curr Cvs '.png']);


%Plot dominating frequency
figure
subplot(1,2,1)
plot(U_meas(simcases),fdomCF(simcases),'bs',U_meas(allcases),fdom_measCF(allcases),'ro')
grid on
legend('Sim','Exp', 'Location', 'Best')
ylabel('Dominating frequency (Hz) ')
xlabel('Towing speed (m/s)')
title('Cross-flow')
%title(['Dominating frequency comparison: NDP38m' curr 'flow' Cvs])
subplot(1,2,2) 
plot(U_meas(simcases),fdomIL(simcases),'bs',U_meas(allcases),fdom_measIL(allcases),'ro')
grid on
legend('Sim','Exp', 'Location', 'Best')
ylabel('Dominating frequency (Hz) ')
xlabel('Towing speed (m/s)')
title('In-line')
saveas(gcf,['Freq_NDP' curr Cvs '.png']);


figure 
subplot(1,2,1)
plot(U_meas(simcases),meanSTDSsimCF(simcases),'bs', U_meas(allcases), meanstress_measCF(allcases), 'ro')
grid on
legend('Pred','Meas', 'Location', 'Best')
ylabel('Mean std of stresses (MPa) ')
xlabel('Towing speed (m/s)')
title('Cross-flow')
%title(['Cross-flow' curr 'flow, Cv=' Cvs])
subplot(1,2,2) 
plot(U_meas(simcases),meanSTDSsimIL(simcases),'bs',U_meas(allcases),meanstress_measIL(allcases),'ro')
grid on
legend('Pred','Meas', 'Location', 'Best')
ylabel('Mean std of stresses (MPa)')
xlabel('Towing speed (m/s)')
title('In-line')
%title(['Inline' curr 'flow, Cv=' Cvs])
saveas(gcf,['MeanstdStress' curr Cvs '.png']);
end

 




