%%This script is used for loading and saving the processed experimental NDP 
%%data for 41% straked risers from an excel-file and a mat-file, as well as simulating selected
%%cases and storing the simulation output.  
clear all
close all

%% Pipe property
D=0.027;          %Diameter of riser
L=38;             %Length of riser
E=36.2e9;         %Elastic modulus
nnod = 502;       %Number of nodes
nelem = nnod-2;   %Number of elements
%% Load measured fatigue, displacement and stress
MeasPath=['C:\Users\dreng\OneDrive\Dokumenter\NTNU\Riflex_run\Meas\']; 
MeasData=importdata([MeasPath 'straked_1w.xlsx']); %Read NDP data from excel sheet
MatMeasPath=['C:\Users\dreng\OneDrive\Dokumenter\NTNU\Riflex_run\High Mode VIV Model tests\Raw data\'];
MatMeasData=load([MatMeasPath 'strakedmeasdata1w.mat']); %Read NDP data from generated mat-files

%Coordinates for measured strains, CF and IL
cordsCF=[2.555	3.084	3.224	4.155	6.030	8.609	8.889	10.285	13.676	16.452	16.891	19.997 ...
        20.193	21.393	22.460	23.165	25.153	26.254	28.863	29.365	31.191	33.005	36.559	37.322];
cordsIL=[1.143 2.555 3.084 3.224 4.155 5.759 6.030 7.664 8.216 8.609 8.889 9.703 10.285 13.676 13.772 ...
        15.393 16.452 16.547 16.891 16.997 20.193 21.393 21.603 22.460 23.165 25.153 25.442 26.254 ...
        27.532 28.698 28.863 29.365 31.191 31.415 32.796 33.005 35.549 36.559 36.824 37.322];

%Coordinates for measured displacements, same IL and CF    
cordacc=[4.155 8.609 13.676 16.891 21.393 25.153 28.863 33.005]; 
cordSpec=cordacc(4); 

%Read data from excel sheet
CaseID=MeasData.data.INFO(1:end,1); %CaseID for all cases
U_meas=MeasData.data.INFO(1:end,2); %Current speed for all cases [m/s]
Ten=MeasData.data.INFO(1:end,10);   %Mean effective tension

%Read data from mat-file
fat_measCF=MatMeasData.fs_rfcfd2CF; %CF fatigue at 1xomega 
maxfat_measCF=max(fat_measCF,[],2); %Max CF fatigue along riser
meanfat_measCF=mean(fat_measCF,2);  %Mean CF fatigue along riser

fat_measIL=MatMeasData.fs_rfcfdIL2; %IL fatigue at 2xomega
maxfat_measIL=max(fat_measIL,[],2); %Max IL fatigue along riser
meanfat_measIL=mean(fat_measIL,2);  %Mean IL fatigue along riser

disp_measCF=MatMeasData.ADy2;  %CF displacement std (1xomega)
disp_measIL=MatMeasData.ADx2;  %IL displacement std (2xomega)

stress_measCF=MatMeasData.stdSsCF2;      %CF stress std
meanstress_measCF=mean(stress_measCF,2); %Mean CF stress std along riser
stress_measIL=MatMeasData.stdSsIL2;      %IL stress std
meanstress_measIL=mean(stress_measIL,2); %Mean IL stress std along riser

fdom_measCF=MatMeasData.fdomsCF(:,4);  %Dominating measured strain frequency CF at sensor 5/19/36/max curv repsonse (column 1/2/3/4)
fdom_measIL=MatMeasData.fdomsIL(:,4);  %Dominating measured strain frequency IL at sensor 5/19/36/max curv response
fdom_measdCF=MatMeasData.fdomdCF(:,3); %Dominating measured displacement frequency CF at sensor 5/19/36
fdom_measdIL=MatMeasData.fdomdIL(:,3); %Dominating measured displacement frequency IL at sensor 5/19/36

save([MeasPath 'strakedmeasdata.mat'])

load([MeasPath 'strakedmeasdata.mat']);

%% Provide parameters for input-files
%%Regular wave data (to be printed to inpmod)
inrwc = 1; 
amplit = 10^-9; 
wavdir = 0; 

%% Read template file
templatePath='C:\Users\dreng\OneDrive\Dokumenter\NTNU\Riflex_run\Template';
inpfilePath='C:\Users\dreng\OneDrive\Dokumenter\NTNU\Riflex_run\Inputfile';

tempFileName='ndp38m0';

simcases = 23:1:44; %Cases selected for simulation, numbers refer to how the cases are listed in CaseID.
allcases = 23:1:44; %Vector including all uniform or shear flow cases, different than simcases if a limited number of cases are simulated
                    %Uniform flow cases: 23:1:44;
                    %Shear flow cases: 1:1:22;
for ic=simcases
    inpFileName=['ndp38m' num2str(CaseID(ic))]; 
    tempInpmod = fileread([templatePath '\\' tempFileName '_Strakesinpmod.inp']);  %Read the template input file
    tempInpmod = strjoin(strsplit(tempInpmod,'\r\n'),'\n');                        %Split read string at specified delimiter
    tempStamod = fileread([templatePath '\\' tempFileName '_Strakesstamod.inp']);  %Read the template input file
    tempStamod = strjoin(strsplit(tempStamod,'\r\n'),'\n');                        %Split read string at specified delimiter
    tempDynmod = fileread([templatePath '\\' tempFileName '_Strakesdynmod.inp']);  %Read the template input file
    tempDynmod = strjoin(strsplit(tempDynmod,'\r\n'),'\n');                        %Split read string at specified delimiter
    
    
    %Define time step by the measured CF period for each case. Defined in dynmod: 40 time
    %steps per CF period, 400 CF periods simulated
    CF_period=1/fdom_measCF(ic); 
    %              'inrwc amplit   period   wavdir          
    data = num2str([inrwc amplit   CF_period   wavdir]); 
    caseInp = strrep(tempInpmod, '_PERIODDATA_', data);              %Replace the contents _PERIODDATA_ in the original file with new contents
    fid = fopen([inpfilePath '\\' inpFileName '_inpmod.inp'],'wt');  %Write in the file
    fprintf(fid, '%s', caseInp);
    fclose(fid);
    
    %Define tension
    xxxTen=Ten(ic)/1000;  % kN
    %     'line-id            ilseg ilnode ildof  rlmag       chicoo
    data=['line1   ' num2str( [2     nnod/2      2   xxxTen]) '  GLOBAL'];
    caseInp = strrep(tempStamod, '__TEN__',data);                          %Replace the contents __TEN__ in the original file with new contents
    tempStamod = caseInp;

    %Define current
    %' nlcomp  icurin  curfac  iwindin
    xxxCur=U_meas(ic);
    if ic<23
        data=num2str([1  2 xxxCur 0]);  %Sheared profile
        curr = 'Shear';
    else             
        data=num2str([1  1 xxxCur 0]);  %Uniform profile
        curr = 'Uniform'; 
    end
    caseInp = strrep(tempStamod, '__CURR__',data);                   %Replace the contents __CURR__ in the original file with new contents
    fid = fopen([inpfilePath '\\' inpFileName '_stamod.inp'],'wt');  %Write in the file
    fprintf(fid, '%s', caseInp);
    fclose(fid);
  
    
    %Copy dynmod file, no replacement of the content
    fid = fopen([inpfilePath '\\' inpFileName '_dynmod.inp'],'wt');   %Write in the file
    fprintf(fid, '%s', tempDynmod);
    fclose(fid);
    
    %Run VIVANA-TD
    res(ic)=riflex('isd',inpfilePath, inpFileName); 
    
    %% Extract and store TD analysis results
    cd(['C:\Users\dreng\OneDrive\Dokumenter\NTNU\Riflex_run\Inputfile\STRAKES\NewCDsims\OnlyQuadDamp\Strakespresenceaccounted(H)']) %Directory for storing simulation data
    data=load([inpfilePath '\' inpFileName '_noddis.asc']);          %Displacement data
    curvdata=load([inpfilePath '\' inpFileName '_elmcur.asc']);      %Curvature data
    save([inpFileName 'dispdata.mat'],'data');                       %Store displacement data in mat-files
    save([inpFileName 'curvdata.mat'],'curvdata');                   %STore curvature data in mat-files
end


