% readTimeDomainResults  Reads in results from a single simulation 
% 

close all
clear all
clc

%Define number of conditions
n = 5;  

%Preallocate requested means and standard deviations
MeanOffsetSurge = zeros(1,n); 
MeanOffsetPitch = zeros(1,n); 
StdSurge = zeros(1,n); 
StdSway = zeros(1,n); 
StdHeave = zeros(1,n); 
StdRoll = zeros(1,n); 
StdPitch = zeros(1,n); 
StdYaw = zeros(1,n); 
MeanRotorSpeed = zeros(1,n); 
StdRotorSpeed = zeros(1,n); 
MeanTowerBaseMomentY = zeros(1,n); 
MeanTowerBaseMomentZ = zeros(1,n); 
StdTowerBaseMomentY = zeros(1,n); 
StdTowerBaseMomentZ = zeros(1,n); 
MeanPower = zeros(1,n); 

%Preallocate number of stress cycles and fatigue damage
N = zeros(n,1); 
hourFatDamageSingleConditons = zeros(n,1); 
%Cross-section parameters 
D_y = 6.5; 
thk = 0.027; 
D_i = D_y-2*thk; 
A = pi/4*(D_y^2-D_i^2); 
I_y = pi/64*(D_y^4-D_i^4); 
I_z = I_y; 
%Point of consideration in cross-section
theta = 3*pi/2; 

%Parameters for fatigue damage computation
loga_bar = [12.164, 15.606];  
beta = [3 5]; %Equal to m
K = [1/10^loga_bar(1) 1/10^loga_bar(2)]; 
stresslim = 52.63; 
tref = 0.025;
k = 0.2; 
twentyYearsInHours = 24*365*20; 

%Define probability vector for relevant conditions !!!!!
probVector = [0.0237 0.0818 0.0716 0.0402 0.0356]; 

hourFatDamage = 0; %Need to sum up fatigue damage from each condtion, initially set to 0

%% User-defined input
for i = 1:n
condtion = num2str(i);    
folder = strcat('C:\Users\dreng\OneDrive\Dokumenter\NTNU\Hst 2018\Integrated dynamic analysis of wind turbines\SIMA\CSC5MW\phase331\phase331_',condtion);
prefix = 'sima';
hullBody = 1; % typically 1 

%% READ SIMULATION OUTPUT
%==========================================================================
%%READ SIMULATION OUTPUT
    % Read the SIMO results text file to get the channel names and number
    % of steps
    [nchan, nts, dt, chanNames] = readSIMO_resultstext([folder '\results.txt']);
    % Read the binary file
    BB = read_simoresults([folder '\results.tda'],nts);
    sizeBB = size(BB);
    if (sizeBB(1)<nts || nts<1); disp('Unable to read SIMO results'); return; end;
    % Determine which channels to read for the platform motions, wave
    % elevation
    [chanMotions, chanWave] = getchannelNumbers(chanNames,hullBody);
    if (chanMotions(1)<1 || chanWave<1); disp('Unable to read SIMO results'); return; end;
    time_SIMO = BB(:,2);
    
    % summarize data in matrix
    PlatMotions = BB(:,chanMotions);
    SurgeMotions = PlatMotions(:,1);
    SwayMotions = PlatMotions(:,2); 
    HeaveMotions = PlatMotions(:,3); 
    RollMotions = PlatMotions(:,4); 
    PitchMotions = PlatMotions(:,5);
    YawMotions = PlatMotions(:,6); 
    wave = BB(:,chanWave);

    % Read the wind turbine results 
    fname = [folder '\' prefix '_witurb.bin'];
    BB = read_rifbin(fname,0,26);
    sizeBB = size(BB);
    Nt = sizeBB(1); % get the number of time steps
    if Nt<2; disp('Unable to read RIFLEX wind turbine results'); return; end; 
    
    time_RIFLEX = BB(:,2);
    omega = BB(:,3)*pi/180; % convert from deg/s to rad/s
    genTq = BB(:,5); 
    genPwr = BB(:,6)*94.4/100; % generator efficiency included
    azimuth = BB(:,7); 
    HubWindX = BB(:,8);
    HubWindY = BB(:,9);
    HubWindZ = BB(:,10);
    AeroForceX = BB(:,11);
    AeroMomX = BB(:,14);
    Bl1Pitch = BB(:,17);
    Bl2Pitch = BB(:,18);
    Bl3Pitch = BB(:,19); 

    % Read the RIFLEX force output file
    fname = [folder '\' prefix '_elmfor.bin'];
    BB = read_rifbin(fname,Nt);
    sizeBB = size(BB);
    if(sizeBB(1)<Nt); disp('Unable to read RIFLEX force results'); return; end;  

    % Tower Base
    TowerBaseAxial  = BB(:,3);
    TowerBaseTors   = BB(:,4);
    TowerBaseBMY    = BB(:,5);
    TowerBaseBMZ    = BB(:,7);
    TowerBaseShearY = BB(:,9);
    TowerBaseShearZ = BB(:,11);

    % Tower Top
    TowerTopAxial  = BB(:,13);
    TowerTopTors   = BB(:,14);
    TowerTopBMY    = BB(:,16); % end 2
    TowerTopBMZ    = BB(:,18);
    TowerTopShearY = BB(:,20);
    TowerTopShearZ = BB(:,22);    
    
    % Blade 1
    bl1Axial        = BB(:,23);
    bl1Tors         = BB(:,24);
    bl1BMY          = BB(:,25);
    bl1BMZ          = BB(:,27);
    bl1ShearY       = BB(:,29);
    bl1ShearZ       = BB(:,31);
    
    % Blade 2
    bl2Axial        = BB(:,33);
    bl2Tors         = BB(:,34);
    bl2BMY          = BB(:,35);
    bl2BMZ          = BB(:,37);
    bl2ShearY       = BB(:,39);
    bl2ShearZ       = BB(:,41);
    
    
    clear('fid','fname','data','BB','sizeBB','chanNames','chanWave','dt')
%%END READ SIMULATION OUTPUT

%==========================================================================

%% DESCRIPTION OF TIME SERIES available in the workspace
% =========================================================================
% Platform motions and wave elevation:
%   Time variable:             time_SIMO (mx1)  : s
%   Platform positions:        PlatMotions (mx6): m,m,m,deg,deg,deg
%   Wave elevation at origin   wave(mx1)        : m 

% Wind turbine results : 
%   Time variable:             time_RIFLEX (jx1): s
%   Thrust (shaft x):          AeroForceX (jx1) : kN
%   Aero. torque (about shaft):AeroMomX (jx1)   : kNm (rotor inertia NOT INCLUDED) 
%   Wind speed (shaft x):      HubWindX (jx1)   : m/s (at hub pos)
%   Wind speed (shaft y):      HubWindY (jx1)   : m/s (at hub pos)
%   Wind speed (shaft z):      HubWindZ (jx1)   : m/s (at hub pos)
%   Rotor speed:               omega (jx1)      : rad/s
%   Generator power:           genPwr (jx1)     : kW (including efficiency)
%   Generator torque:          genTq (jx1)      : kNm (HSS)
%   Azimuth angle:             azimuth (jx1)    : deg 

% Internal force results at the tower base: 
%   Time variable:              time_RIFLEX (jx1)       : s
%   Axial force at tower base:  TowerBaseAxial (jx1)    : kN  (DOF1)
%   Bending mom. Y at tow base: TowerBaseBMY (jx1)      : kNm (DOF3)
%   Bending mom. Z at tow base: TowerBaseBMZ (jx1)      : kNm (DOF5)
%   Shear force Y at tow base:  TowerBaseShearY (jx1)   : kN  (DOF7)
%   Shear force Z at tow base:  TowerBaseShearZ (jx1)   : kN  (DOF9)
%   Torsional moment tow base:  TowerBaseTors (jx1)     : kNm (DOF2)

% Internal force results at the blade root for blade 1: 
%   Time variable:              time_RIFLEX (jx1)       : s
%   Axial force at tower base:  bl1Axial (jx1)          : kN  (DOF1)
%   Bending mom. Y at tow base: bl1BMY (jx1)            : kNm (DOF3)
%   Bending mom. Z at tow base: bl1BMZ (jx1)            : kNm (DOF5)
%   Shear force Y at tow base:  bl1ShearY (jx1)         : kN  (DOF7)
%   Shear force Z at tow base:  bl1ShearZ (jx1)         : kN  (DOF9)
%   Torsional moment tow base:  bl1Tors (jx1)           : kNm (DOF2)

% Internal force results at the blade root for blade 2: 
%   Time variable:              time_RIFLEX (jx1)       : s
%   Axial force at tower base:  bl2Axial (jx1)          : kN  (DOF1)
%   Bending mom. Y at tow base: bl2BMY (jx1)            : kNm (DOF3)
%   Bending mom. Z at tow base: bl2BMZ (jx1)            : kNm (DOF5)
%   Shear force Y at tow base:  bl2ShearY (jx1)         : kN  (DOF7)
%   Shear force Z at tow base:  bl2ShearZ (jx1)         : kN  (DOF9)
%   Torsional moment tow base:  bl2Tors (jx1)           : kNm (DOF2)

% =========================================================================
%% Post-processing
%  Statistical analysis, fatigue calculation, etc
%  Remember to cut out the first part of the time series
%  Hint: 
%           t_start = 400;
%           indS = sum(time_SIMO<=t_start);
%           mean(PlatMotions(indS:end))


%Define where stationary process starts
t_start = 400;
indS = sum(time_SIMO<=t_start);

%Compute stationary stress time series
TowerBaseAxialForce = TowerBaseAxial(indS:end)*10^3; %N
TowerBaseMomentY = -1*TowerBaseBMY(indS:end)*10^3; %Nm
TowerBaseMomentZ = TowerBaseBMZ(indS:end)*10^3; %Nm

stressSx (i,:) = (TowerBaseAxialForce/A + TowerBaseMomentY/I_y*D_y/2*sin(theta)...
    +TowerBaseMomentZ/I_z*D_y/2*cos(theta))*10^-6; %N/mm^2 - MPa

%Compute requested mean and standard deviation
MeanOffsetSurge(i) = mean(SurgeMotions(indS:end)); 
MeanOffsetPitch(i) = mean(PitchMotions(indS:end)); 
StdSurge(i) = std(SurgeMotions(indS:end)); 
StdSway(i) = std(SwayMotions(indS:end)); 
StdHeave(i) = std(HeaveMotions(indS:end));
StdRoll(i) = std(RollMotions(indS:end));
StdPitch(i) = std(PitchMotions(indS:end));
StdYaw(i) = std(YawMotions(indS:end));
MeanRotorSpeed(i)= mean(omega(indS:end));
MeanTowerBaseMomentY(i) = mean(TowerBaseMomentY); 
MeanTowerBaseMomentZ(i) = mean(TowerBaseMomentZ); 
StdTowerBaseMomentY(i) = std(TowerBaseMomentY); 
StdTowerBaseMomentZ(i) = std(TowerBaseMomentZ); 
MeanPower(i) = mean(genPwr(indS:end)); 
%Do rainflowcounting
time = time_RIFLEX(indS:end)-t_start; 
rainflowcounting

%Find hourly fatigue damage 
hourFatDamageSingleConditons(i) = cc2dam_2slope(RFC, beta, K, stresslim, thk, tref, k); 

hourFatDamage = hourFatDamage + hourFatDamageSingleConditons(i)*probVector(i); 

end

twentyYearFatDamage = hourFatDamage*twentyYearsInHours; 
twentyYearPower = MeanPower*twentyYearsInHours; %kWh
yearlyPower = twentyYearPower/20; %kWh
 

